@@ -739,10 +739,12 @@ class Broker(WithInventorySatellite):
                 u'configuration_incarnation_uuid': configuration_incarnation_uuid
             }
             tmp_broks_b64 = con.get(u'get_broks', param, wait=u'long')
-            
+            receive_time = time.time()
             input_data = base64.b64decode(tmp_broks_b64)
             del tmp_broks_b64  # release memory asap
             
+            b64_time = time.time()
+            
             protocol, input_data = self.__detect_protocol_and_get_input(input_data)
             nb_remaining_broks = 0
             # Now based on the protocol version, get broks as pickle
@@ -763,6 +765,7 @@ class Broker(WithInventorySatellite):
                 sat_entry['con'] = None
                 return
             
+            uncompress_time = time.time()
             # Final Step: load the broks from pickle
             try:
                 broks = SafeUnpickler.loads(pickle_broks, u'broks')
@@ -771,8 +774,17 @@ class Broker(WithInventorySatellite):
                 logger.error('%s Fail to load broks data from %s %s with : [%s]' % (_GET_BROKS_STR, sat_type, sat_entry['name'], exp))
                 sat_entry['con'] = None
                 return
-            
-            logger.debug('%s %s Got %4d broks, remaining broks: %4s broks' % (_GET_BROKS_STR, sat_entry['name'], len(broks), nb_remaining_broks))
+            unpickle_time = time.time()
+            logger.debug('%s %s Got %4d broks, remaining broks: %4s broks total:%.3fs [recv:%.3fs, b64_decode:%.3fs, uncompress:%.3fs, unpickle:%.3fs]' % (
+                _GET_BROKS_STR,
+                sat_entry['name'],
+                len(broks),
+                nb_remaining_broks,
+                unpickle_time - before,
+                receive_time - before,
+                b64_time - receive_time,
+                uncompress_time - b64_time,
+                unpickle_time - uncompress_time))
             
             sat_entry['sent_broks_this_turn'] += len(broks)
             
@@ -1514,6 +1526,8 @@ class Broker(WithInventorySatellite):
         nb_broks_managed = 0
         nb_broks_at_start = len(broks)
         
+        brok_prepare_time = 0
+        
         internal_modules = self.modules_manager.get_internal_instances()
         have_internal_modules = len(internal_modules) != 0
         if have_internal_modules:
@@ -1537,7 +1551,9 @@ class Broker(WithInventorySatellite):
                     break
                 
                 nb_broks_managed += 1
-                
+                before_prepare = time.time()
+                b.prepare()
+                brok_prepare_time = brok_prepare_time + (time.time() - before_prepare)
                 # Ok, we can get the brok, and doing something with it
                 # REF: doc/broker-modules.png (4-5)
                 # We un serialize the brok before consume it
@@ -1559,7 +1575,10 @@ class Broker(WithInventorySatellite):
         sorted_modules_stats = self.local_module_stats.keys()
         sorted_modules_stats.sort()
         if sorted_modules_stats:
-            logger.info('%s                            ----- Details of INTERNAL modules execution time: %s' % (_MANAGE_BROKS_STR, ', '.join(['(%s=%.3fs)' % (k, self.local_module_stats[k]) for k in sorted_modules_stats])))
+            logger.info('%s                            ----- Details of INTERNAL brok deserialization time:%.3fs modules execution time: %s' % (
+                _MANAGE_BROKS_STR,
+                brok_prepare_time,
+                ', '.join(['(%s=%.3fs)' % (k, self.local_module_stats[k]) for k in sorted_modules_stats])))
         
         # #### STEP4: get modules objects and call modules ticks
         # Maybe external modules raised 'objects' we should get them
