@@ -135,20 +135,7 @@ class Receiver(WithInventorySatellite):
     })
     
     # Labels for the logging
-    command_log_labels = {
-        'PROCESS_HOST_CHECK_RESULT'   : 'Host result',
-        'PROCESS_SERVICE_CHECK_RESULT': 'Check result',
-        'ACKNOWLEDGE_HOST_PROBLEM'    : 'Host acknowledge',
-        'ACKNOWLEDGE_SVC_PROBLEM'     : 'Check acknowledge',
-        'REMOVE_HOST_ACKNOWLEDGEMENT' : 'Host acknowledge deleteion',
-        'REMOVE_SVC_ACKNOWLEDGEMENT'  : 'Check acknowledge deletion',
-        'SCHEDULE_FORCED_HOST_CHECK'  : 'Schedule immediate host',
-        'SCHEDULE_FORCED_SVC_CHECK'   : 'Schedule immediate check',
-        'SCHEDULE_HOST_DOWNTIME'      : 'Create host downtime',
-        'SCHEDULE_SVC_DOWNTIME'       : 'Create check downtime',
-        'DEL_ALL_SVC_DOWNTIMES'       : 'Delete check downtimes',
-        'DEL_ALL_HOST_DOWNTIMES'      : 'Delete host downtimes',
-    }
+    command_log_labels = ExternalCommandManager.command_log_labels
     
     
     def __init__(self, config_file, is_daemon, do_replace, debug, debug_file, daemon_id=0):
