@@ -46,7 +46,9 @@ from shinken.runtime_stats.threads_dumper import WatchDogThreadDumper
 from shinken.safepickle import SafeUnpickler
 from shinken.satellite import BaseSatellite, IForArbiter as IArb, Interface
 from shinken.scheduler import Scheduler
+from shinken.schedulerlink import SchedulerDumpCheckAuthenticationVerifier
 from shinken.util import force_memory_trimming, to_float_kb
+from shinken.webui import bottlecore as bottle
 
 if TYPE_CHECKING:
     from shinken.misc.type_hint import Optional, Dict, Any
@@ -102,7 +104,7 @@ class IChecks(Interface):
         
         get_checks_time = time.time() - get_checks_time
         if get_checks_time > 0.1 or cpick_time > 0.05 or zcompress_time > 0.05 or b64_time > 0.05:
-            logger.warning('get_checks:: total time:[%.3f] cpick:[%.3f] zcompres:[%.3f] b64encode:[%.3f] nb_check_send:[%d] b64_size:[%d]' % (get_checks_time, cpick_time, zcompress_time, b64_time, len(res), len(_b64)))
+            logger.warning('[ PERF ] get_checks:: total time:[%.3f] cpick:[%.3f] zcompres:[%.3f] b64encode:[%.3f] nb_check_send:[%d] b64_size:[%d]' % (get_checks_time, cpick_time, zcompress_time, b64_time, len(res), len(_b64)))
         return _b64
     
     
@@ -457,6 +459,68 @@ class IStats(IStatsInterface):
     
     
     call_for_retention.need_lock = True
+    
+    
+    # A user can ask (with the help of the support) to dump in a /tmp csv file about
+    # * this scheduler (name, dump time, realm)
+    # * all checks with epoch_to_go, ids, check/retry interval, cpu time
+    # NOTE: there is a protection to not allow anyone to call it (fill disk, etc)
+    #       the password is ....
+    #       .... really? You did think I'll put it in the source code? Nope
+    def export_data(self, authentication_token):
+        # type: (unicode) -> Dict[unicode,Any]
+        
+        export_logger = LoggerFactory.get_logger(u'EXPORT DATA')
+        
+        if not self.app.scheduler__export_data__enabled:
+            export_logger.warning(u'Request from Arbiter IP〖%(ip)s〗fails. Export is disabled by configuration parameter 〖scheduler__export_data__enabled〗' % {u'ip': bottle.request.environ.get(u'REMOTE_ADDR', u'(unknown)')})
+            return {u'state': u'ERROR', u'error': u'The Scheduler configuration disabled data export with the scheduler__export_data__enabled parameter.'}
+        
+        # Too early, the scheduler is just booting
+        if not hasattr(self.app.sched, u'instance_name'):
+            export_logger.warning(u'Request from Arbiter IP〖%(ip)s〗fails. Scheduler is not ready (initialisation ongoing)' % {u'ip': bottle.request.environ.get(u'REMOTE_ADDR', u'(unknown)')})
+            return {u'state': u'ERROR', u'error': u'The Scheduler does not have any configuration'}
+        
+        # Spare
+        if not self.app.is_activated():
+            return {u'state': u'OK', u'skip':True, u'data': self.app.sched.get_export_data_struct()}
+        
+        # a void authentication_token mean that the caller is asking for an anonymous dump, it's always ok
+        dump_with_private_information = False
+        if authentication_token != '':
+            
+            # Give the token to the verifier. If the caller did ask for auth but fail, just give up and give it the error
+            scheduler_name = self.app.sched.instance_name
+            daemon__export_data__password = self.app.daemon__export_data__password
+            
+            is_ok, err = SchedulerDumpCheckAuthenticationVerifier().is_authentication_token_authorized(authentication_token, scheduler_name, daemon__export_data__password)
+            if not is_ok:
+                export_logger.warning(u'Request from Arbiter IP〖%(ip)s〗fails. %(error)s' % {
+                    u'ip'   : bottle.request.environ.get(u'REMOTE_ADDR', u'(unknown)'),
+                    u'error': err
+                })
+                return {u'state': u'ERROR', u'error': err}
+            # The token was valid, we can dump with private info, like names
+            dump_with_private_information = True
+        
+        # Maybe the scheduler is NOT initialized, then error, because we don't know if we will have jobs or not
+        if not self.app.have_configuration:
+            export_logger.warning(u'Request from Arbiter IP〖%(ip)s〗fails. Scheduler is not ready (waiting for configuration)' % {u'ip': bottle.request.environ.get(u'REMOTE_ADDR', u'(unknown)')})
+            return {u'state': u'ERROR', u'error': u'The Scheduler does not have any configuration'}
+        
+        # NOTE: Maybe the scheduler is just a spare, then it will just dump nothing, it's not an error case
+        start_time = time.time()
+        data = self.app.sched.export_data(self.app.realm, dump_with_private_information)
+        export_logger.info(u'%(type)s export of %(nb_elements)s elements in %(duration).3fs from Arbiter IP〖%(ip)s〗' % {
+            u'type'       : u'full' if dump_with_private_information else u'anonymous',
+            u'nb_elements': len(data.get(u'entries', [])),
+            u'duration'   : time.time() - start_time,
+            u'ip'         : bottle.request.environ.get(u'REMOTE_ADDR', u'(unknown)')
+        })
+        return {u'state': u'OK', u'data': data}
+    
+    
+    export_data.need_lock = False  # already use a lock on checks, do not need the big one
 
 
 class IForArbiter(IArb):
@@ -634,6 +698,8 @@ class Shinken(BaseSatellite):
         self.brokers = {}
         
         self.realm = ''
+        self.daemon__export_data__password = u''  # This password is used for checks dumps: we only add names if the password is OK
+        self.scheduler__export_data__enabled = True  # If the dump is allowed, even in anonymous mode
         self.last_arbiter = {}
         
         self.have_modules = False  # to know if we must load or update teh modules in the modules manager
@@ -644,7 +710,6 @@ class Shinken(BaseSatellite):
         self._have_pending_configuration = False
         self.partial_configuration_incarnation = None  # type: Optional[PartConfigurationIncarnation]
         self._partial_is_activated = False
-        
     
     
     def _reset_managed_configuration(self):
@@ -873,6 +938,8 @@ class Shinken(BaseSatellite):
         satellites = new_conf['satellites']
         instance_name = new_conf['instance_name']
         skip_initial_broks = new_conf['skip_initial_broks']
+        # NOTE: scheduler__export_data__enabled was added in a fix, so maybe the arbiter is not up-to-date
+        self.scheduler__export_data__enabled = new_conf.get(u'scheduler__export_data__enabled', True)
         realm = new_conf['realm']
         _logger.info(u'Configuration %s is being parsed and loaded' % configuration_incarnation)
         
@@ -919,6 +986,9 @@ class Shinken(BaseSatellite):
         # old arbiter did not send this
         self.conf.default_properties_values = getattr(self.conf, 'default_properties_values', {})
         
+        # NOTE: daemon__export_data__password was added in a fix, so maybe the arbiter is not up-to-date
+        self.daemon__export_data__password = getattr(self.conf, 'daemon__export_data__password', u'')
+        
         self.realm = realm
         
         self.override_conf = override_conf
