@@ -1537,31 +1537,38 @@ class Executor(BaseSatellite):
             logger.error(str(x))
             logger.error(traceback.format_exc())
             sys.exit(1)
-    
-    
+
+
     def compute_request_limit(self):
         if os.name == 'nt':
             self.request_limit = -1
             return self.request_limit
-        
+    
         if not self.have_configuration:
             self.request_limit = 0
             return self.request_limit
-        
-        total_cpu_time_todo_in_poller = (self._get_cpu_time_action_todo() + self._get_cpu_time_action_todo_in_workers())
+    
+        _main_process_todo_queue = self._get_cpu_time_action_todo()
+    
+        total_cpu_time_todo_in_poller = _main_process_todo_queue
         total_cpu_time_todo_in_poller_with_margin = total_cpu_time_todo_in_poller / 2.0
-        
-        if total_cpu_time_todo_in_poller_with_margin >= self._cpu_time_limit:
+    
+        # We want to have 1s of job ahead us in our main process buffer
+        wish_limit = 1 * self._cpu_time_limit
+        if total_cpu_time_todo_in_poller_with_margin >= wish_limit:
             request_limit = 0
         else:
-            request_limit = self._cpu_time_limit - total_cpu_time_todo_in_poller_with_margin
-        
+            request_limit = wish_limit - total_cpu_time_todo_in_poller_with_margin
+    
+        # If the loop turn is too high, slow a bit until we reach an acceptable time
+        # NOTE: this is a warning because such case should not be seen, even on large env
         self.executor_in_overload = self.avg_loop_time.get_avg(0) > self._polling_interval
         if self.executor_in_overload:
-            logger.warning(u'[limiter] loop time too high [%.3f] we will limit the executor.' % (self.avg_loop_time.get_avg(0)))
+            logger.warning('[limiter] loop time too high [%.3f] we will limit the executor.' % (self.avg_loop_time.get_avg(0)))
             request_limit = 0
-        logger.debug(u'[limiter] todo/asking/limit [%.3f]/[%.3f]/[%d].' % (total_cpu_time_todo_in_poller, request_limit, self._cpu_time_limit))
-        
+    
+        logger.debug(u'[limiter] [todo main daemon=%.3f] [ Hard limit=%d ] => [ asking this turn=%.3f ]' % (_main_process_todo_queue, self._cpu_time_limit, request_limit))
+    
         self.request_limit = request_limit
         return request_limit
     
@@ -1588,6 +1595,7 @@ class Executor(BaseSatellite):
         
         actions_to_remove_from_actions_to_queue = []
         worker_to_skip = []
+        
         for action in self._actions_to_give_at_worker:
             
             if action.status != 'inpoller':
