@@ -25,7 +25,8 @@
 from collections import deque
 
 from item import InheritableItem, InheritableItems
-from shinken.log import logger, naglog_result
+from shinken.log import naglog_result
+from shinken.misc.configuration_error_log import log_configuration_error
 from shinken.misc.type_hint import TYPE_CHECKING
 from shinken.property import BoolProp, IntegerProp, StringProp, AclShareProp, LinkToAnotherObjectProp, LinkToOthersObjectsProp, RawProp
 
@@ -67,6 +68,7 @@ class Contact(InheritableItem):
         'default_submit_to_staging'    : BoolProp(default='1'),  # for synchronizer by pass working area
         'acl_try_check_on_poller'      : BoolProp(default='1'),  # for synchronizer right
         'acl_try_check_on_synchronizer': BoolProp(default='1'),  # for synchronizer right
+        'acl_show_external_url'        : BoolProp(default='1', fill_brok=['full_status']),  # for synchronizer right
         
         ########################### Configuration Structure, like links to others elements
         'contact_name'                 : StringProp(fill_brok=['full_status']),
@@ -91,7 +93,7 @@ class Contact(InheritableItem):
         'address6'                     : StringProp(default='none', fill_brok=['full_status']),
         
         'notificationways'             : LinkToOthersObjectsProp(default='', merging='join', fill_brok=['full_status'], handle_additive_inheritance=True),
-        'password'                     : StringProp(default='NOPASSWORDSET', fill_brok=['full_status']),
+        'password'                     : StringProp(default='', fill_brok=['full_status']),
         'display_name'                 : StringProp(default=''),
         
         'acl_in_tab_history'           : StringProp(default='history_sla', fill_brok=['full_status']),
@@ -199,35 +201,35 @@ class Contact(InheritableItem):
         return r
     
     
-    # Check is required prop are set:
-    # contacts OR contactgroups is need
+    # Check if the contact is valid.
+    # Error message will be logged by log_configuration_error or log_configuration_warning.
     def is_correct(self):
+        # type: () -> bool
         state = True
         cls = self.__class__
         
-        # All of the above are checks in the notificationways part
-        for prop, entry in cls.properties.iteritems():
-            if prop not in _special_properties:
-                if not hasattr(self, prop) and entry.required:
-                    logger.error("[contact::%s] %s property not set" % (self.get_name(), prop))
-                    state = False  # Bad boy...
+        for property_name, property_definition in cls.properties.iteritems():
+            if property_name not in _special_properties and not hasattr(self, property_name) and property_definition.required:
+                state = False
+                log_configuration_error(self, u'The property %s is not set', property_name)
         
-        # There is a case where there is no nw: when there is not special_prop defined
-        # at all!!
+        # If there isn't notificationways it mean that contact is in old format.
+        # So we check if all prop in _special_properties are define
         if self.notificationways == []:
             for p in _special_properties:
                 if not hasattr(self, p):
-                    logger.error("[contact::%s] %s property is missing" % (self.get_name(), p))
                     state = False
+                    log_configuration_error(self, u'The property %s is not set', property_name)
+        
+        # take the alias if we miss the contact_name
+        if not hasattr(self, 'contact_name') and hasattr(self, 'alias'):
+            self.contact_name = self.alias
         
         if hasattr(self, 'contact_name'):
-            for c in cls.illegal_object_name_chars:
-                if c in self.contact_name:
-                    logger.error("[contact::%s] %s character not allowed in contact_name" % (self.get_name(), c))
+            for char in cls.illegal_object_name_chars:
+                if char in self.contact_name:
+                    log_configuration_error(self, u'The character %s is not allowed in name.', char)
                     state = False
-        else:
-            if hasattr(self, 'alias'):  # take the alias if we miss the contact_name
-                self.contact_name = self.alias
         
         return state
     
