@@ -32,15 +32,16 @@ import re
 import time
 
 from item import InheritableItems, MAX_INHERITANCE_LEVEL, _format_inherited_plus_value
-from schedulingitem import SchedulingItem, PROPERTIES_RETRIEVABLE_FROM_COMMAND_TO_HOST
+from schedulingitem import SchedulingItem, PROPERTIES_RETRIEVABLE_FROM_COMMAND_TO_HOST, CUSTOM_DATA_FORMAT
 from shinken.autoslots import AutoSlots
 from shinken.eventhandler import EventHandler
 from shinken.graph import Graph
 from shinken.log import logger, naglog_result
 from shinken.macroresolver import MacroResolver
+from shinken.misc.configuration_error_log import log_configuration_error, log_configuration_warning
 from shinken.misc.type_hint import TYPE_CHECKING
-from shinken.objects.service import Service
 from shinken.objects.proxyitem import proxyitemsmgr
+from shinken.objects.service import Service
 from shinken.property import BoolProp, IntegerProp, CharProp, StringProp, ListProp, EpochProp, RawProp, LinkToOthersObjectsProp
 from shinken.rawdata import TYPE_RAW_DATA_CHECK_RESULT, TYPE_RAW_DATA_FULL
 from shinken.util import \
@@ -322,40 +323,42 @@ class Host(SchedulingItem):
             self.alias = self.host_name
     
     
-    def get_item_tpl_type_for_link(self):
-        # type: () -> str
-        # DONT WORK FOR CLUSTER TPL
-        return 'clustertpls' if self.got_business_rule else "%stpls" % self.get_item_type()
+    def get_item_type_for_synchronizer(self):
+        if self.got_business_rule:
+            if self.is_tpl():
+                return u'clustertpls'
+            else:
+                return u'clusters'
+        else:
+            if self.is_tpl():
+                return u'hosttpls'
+            else:
+                return u'hosts'
     
     
-    # Check is required prop are set:
-    # contacts OR contactgroups is need
+    # Check if the host is valid.
+    # Error message will be logged by log_configuration_error or log_configuration_warning.
     def is_correct(self):
+        # type: () -> bool
         state = True
-        
-        for parent in self.parents:
-            if parent.get_uuid() == self.get_uuid():
-                state = False
-                logger.error("[host::%s] invalid parent value, it cannot be parent of itself " % (self.get_link_shinken()))
+        if next((parent for parent in self.parents if parent.get_uuid() == self.get_uuid()), None):
+            state = False
+            log_configuration_error(self, u'Invalid parent value, it cannot be parent of itself')
         
         cls = self.__class__
-        special_properties = ['check_period', 'notification_interval', 'notification_period']
-        for prop, entry in cls.properties.iteritems():
-            if prop not in special_properties:
-                if not hasattr(self, prop) and entry.required:
-                    logger.error("[host::%s] %s property not set" % (self.get_name(), prop))
-                    state = False  # Bad boy...
+        special_properties = (u'check_period', u'notification_interval', u'notification_period')
+        for property_name, property_definition in cls.properties.iteritems():
+            if property_name not in special_properties and not hasattr(self, property_name) and property_definition.required:
+                state = False
+                log_configuration_error(self, u'The property %s is not set', property_name)
         
-        # Then look if we have some errors in the conf
-        # Juts print warnings, but raise errors
-        for err in self.configuration_warnings:
-            logger.warning("[host::%s] %s" % (self.get_name(), err))
-        
-        # Raised all previously saw errors like unknown contacts and co
-        if len(self.configuration_errors) != 0:
+        for _warning in self.configuration_warnings:
+            log_configuration_warning(self, _warning)
+
+        if self.configuration_errors:
             state = False
-            for err in self.configuration_errors:
-                logger.error("[host::%s] %s" % (self.get_name(), err))
+            for _error in self.configuration_errors:
+                log_configuration_error(self, _error)
         
         if not hasattr(self, 'notification_period'):
             self.notification_period = None
@@ -363,55 +366,56 @@ class Host(SchedulingItem):
         low_flap = self.low_flap_threshold if self.low_flap_threshold != -1 else self.__class__.global_low_flap_threshold
         high_flap = self.high_flap_threshold if self.high_flap_threshold != -1 else self.__class__.global_high_flap_threshold
         if high_flap < low_flap:
-            logger.error("The host '%s' have incoherent flap thresholds (respectively low %s%% and high %s%%)" % (self.host_name, low_flap, high_flap))
+            log_configuration_error(self, u'Flapping enter threshold must not be lower than exit threshold (respectively %s%% and %s%%)', low_flap, high_flap)
             state = False
         
         if self.sla_warning_threshold < self.sla_critical_threshold:
-            logger.error("The host '%s' have incoherent SLA thresholds (respectively critical %s%% and warning %s%%)" % (self.host_name, self.sla_warning_threshold, self.sla_critical_threshold))
+            log_configuration_error(self, u'Critical SLA thresholds must be lower than warning (respectively critical %s%% and warning %s%%)', self.sla_warning_threshold, self.sla_critical_threshold)
             state = False
         
         for custom in self.customs.iterkeys():
-            if self.custom_data_format.search(custom):
-                logger.error("[item::%s] custom property %s is malformed. Special characters are forbidden" % (self.get_name(), custom))
+            if CUSTOM_DATA_FORMAT.search(custom):
+                log_configuration_error(self, u'The DATA name %s is malformed. Special characters are forbidden.', custom)
                 state = False
         
         if getattr(self, 'event_handler', None) and not self.event_handler.is_valid():
-            logger.error("%s: my event_handler %s is invalid" % (self.get_name(), self.event_handler.original_command))
+            log_configuration_error(self, u'The event_handler %s set on this host is not valid.', self.event_handler.get_name())
             state = False
         
         if getattr(self, 'check_command', None) is None:
-            logger.error("%s: I've got no check_command" % self.get_name())
+            log_configuration_error(self, u'The check_command is missing.')
             state = False
         # Ok got a command, but maybe it's invalid
         else:
             if not self.check_command.is_valid():
-                logger.error("%s: my check_command %s is invalid" % (self.get_name(), self.check_command.original_command))
+                log_configuration_error(self, u'The check_command %s set on this host is not valid.', self.check_command.get_name())
                 state = False
             if self.got_business_rule:
                 if self.business_rule and self.business_rule.configuration_errors:
-                    logger.error("[cluster] %s: my rule is invalid: %s" % (self.get_name(), self.business_rule.configuration_errors))
-                    for bperror in self.business_rule.configuration_errors:
-                        logger.error("[host::%s] %s" % (self.get_name(), bperror))
+                    log_configuration_error(self, u'The definition is invalid : ')
+                    for bp_error in self.business_rule.configuration_errors:
+                        log_configuration_error(self, u'%s' % bp_error)
+                    
                     state = False
                 elif self.business_rule is None:
-                    logger.warning("[cluster] %s: my rule is invalid: there is no rule" % (self.get_name(),))
+                    log_configuration_warning(self, u'There is no definition')
         
         if hasattr(self, 'host_name'):
-            for c in cls.illegal_object_name_chars:
-                if c in self.host_name:
-                    logger.error("%s: My host_name got the character %s that is not allowed." % (self.get_name(), c))
+            for char in cls.illegal_object_name_chars:
+                if char in self.host_name:
+                    log_configuration_error(self, u'The character %s is not allowed in name.', char)
                     state = False
         
         for property_name in MINUTE_PROPERTY:
             value = getattr(self, property_name, None)
             if value and value > MINUTES_MAX_DATE_VALUE:
-                logger.error('[item::%s] %s property is too long. Value : %s . The maximum is %s' % (self.get_name(), property_name, value, MINUTES_MAX_DATE_VALUE))
+                log_configuration_error(self, u'The value in %s property is too high. Value is %s, the maximum is %s', property_name, value, MINUTES_MAX_DATE_VALUE)
                 state = False
         
         for property_name in SECOND_PROPERTY:
             value = getattr(self, property_name, None)
             if value and value > SECONDS_MAX_DATE_VALUE:
-                logger.error('[item::%s] %s property is too long. Value : %s . The maximum is %s' % (self.get_name(), property_name, value, SECONDS_MAX_DATE_VALUE))
+                log_configuration_error(self, u'The value in %s property is too high. Value is %s, the maximum is %s', property_name, value, SECONDS_MAX_DATE_VALUE)
                 state = False
         
         return state
@@ -1503,7 +1507,7 @@ class Hosts(InheritableItems):
         
         # and raise errors about it
         for h in host_in_loops:
-            logger.error("The host '%s' is part of a circular parent/child chain!" % h.get_name())
+            log_configuration_error(h, u'The host \'%s\' is part of a circular parent/child chain!', h.get_name())
             r = False
         
         return r
