@@ -34,11 +34,12 @@ from shinken.autoslots import AutoSlots
 from shinken.eventhandler import EventHandler
 from shinken.log import logger, naglog_result
 from shinken.macroresolver import MacroResolver
+from shinken.misc.configuration_error_log import log_configuration_error, log_configuration_warning
 from shinken.misc.html_formater import prepend_explaination_about_set_impact_to_check_output
 from shinken.misc.type_hint import TYPE_CHECKING
 from shinken.objects.item import InheritableItems
 from shinken.objects.proxyitem import proxyitemsmgr
-from shinken.objects.schedulingitem import SchedulingItem, PROPERTIES_RETRIEVABLE_FROM_COMMAND_TO_HOST
+from shinken.objects.schedulingitem import SchedulingItem, PROPERTIES_RETRIEVABLE_FROM_COMMAND_TO_HOST, CUSTOM_DATA_FORMAT
 from shinken.objects.state_id import STATE_ID
 from shinken.property import BoolProp, IntegerProp, CharProp, StringProp, ListProp, LinkToOthersObjectsProp, RawProp, VirtualProp
 from shinken.rawdata import TYPE_RAW_DATA_CHECK_RESULT, TYPE_RAW_DATA_FULL
@@ -244,7 +245,8 @@ class Service(SchedulingItem):
         
         # Virtual because it will look at host value
         'realm'                                : VirtualProp(default='', fill_brok=['full_status', 'check_result', 'next_schedule'], brok_transformation=get_service_realm),
-        
+        u'dfe_key_resolved'                    : StringProp(default=u''),  # Present in Arbiter configuration to Scheduler
+        u'dfe_value_resolved'                  : RawProp(default={}),  # Present in Arbiter configuration to Scheduler
     })
     
     # Mapping between Macros and properties (can be prop or a function)
@@ -312,9 +314,8 @@ class Service(SchedulingItem):
     def __init__(self, params={}, skip_useless_in_configuration=False):
         super(Service, self).__init__(params, skip_useless_in_configuration)
         # Private key use only in arbiter
-        self._dfe_key = ''
-        self._origin_uuid = ''  # uuid of the service use to make the duplicate for each
-        self._dfe_original_name_without_key = ''
+        self._origin_uuid = u''  # uuid of the service use to make the duplicate for each
+        self._dfe_original_name_without_key = u''
     
     
     #######
@@ -382,89 +383,99 @@ class Service(SchedulingItem):
     # so we are switching to known value for the service: WARNING & CRITICAL
     def fix_service_notification_options_inheritance(self):
         # Convert notification options to match d (DOWN on host) to w,c
-        self.notification_options = self.notification_options.replace("d", "w,c")
+        self.notification_options = self.notification_options.replace('d', 'w,c')
     
     
-    # Check is required prop are set:
-    # template are always correct
-    # contacts OR contactgroups is need
+    def get_item_type_for_synchronizer(self):
+        if self.host is None:
+            return u'servicetpls'
+        
+        if self.is_tpl():
+            if self.host.got_business_rule:
+                return u'servicesclustertpls'
+            else:
+                return u'serviceshosttpls'
+        else:
+            if self.host.got_business_rule:
+                return u'servicesclusters'
+            else:
+                return u'serviceshosts'
+    
+    
+    # Check if the service is valid.
+    # Error message will be logged by log_configuration_error or log_configuration_warning.
     def is_correct(self):
+        # type: () -> bool
         state = True
         cls = self.__class__
         
-        source = getattr(self, 'imported_from', 'unknown')
+        service_name = getattr(self, u'service_description', u'unnamed')
+        host_name = getattr(self, u'host_name', u'unnamed')
         
-        desc = getattr(self, 'service_description', 'unnamed')
-        hname = getattr(self, 'host_name', 'unnamed')
+        special_properties = (u'check_period', u'notification_interval', u'host_name', u'hostgroup_name', u'notification_period', u'check_command', u'retry_interval', u'check_interval')
         
-        special_properties = ('check_period', 'notification_interval', 'host_name',
-                              'hostgroup_name', 'notification_period', 'check_command', 'retry_interval', 'check_interval')
-        
-        if getattr(self, 'service_description', None) and getattr(self, 'name', None):
-            logger.error("[item::%s-%s] Service cannot have a service_description and a name." % (self.name, self.service_description))
+        if getattr(self, u'service_description', None) and getattr(self, u'name', None):
+            log_configuration_error(self, u'It cannot have a service_description and a name.')
             state = False
         
         for property_name in MINUTE_PROPERTY:
             value = getattr(self, property_name, None)
             if value and value > MINUTES_MAX_DATE_VALUE:
-                logger.error('[item::%s] %s property is too long. Value : %s . The maximum is %s' % (self.get_name(), property_name, value, MINUTES_MAX_DATE_VALUE))
+                log_configuration_error(self, u'The value in %s property is too high. Value is %s, the maximum is %s', property_name, value, MINUTES_MAX_DATE_VALUE)
                 state = False
         
         for property_name in SECOND_PROPERTY:
             value = getattr(self, property_name, None)
             if value and value > SECONDS_MAX_DATE_VALUE:
-                logger.error('[item::%s] %s property is too long. Value : %s . The maximum is %s' % (self.get_name(), property_name, value, SECONDS_MAX_DATE_VALUE))
+                log_configuration_error(self, u'The value in %s property is too high. Value is %s, the maximum is %s', property_name, value, SECONDS_MAX_DATE_VALUE)
                 state = False
         
-        for prop, entry in cls.properties.iteritems():
-            if prop not in special_properties:
-                if not hasattr(self, prop) and entry.required:
-                    logger.error("The service %s on host '%s' does not have %s" % (desc, hname, prop))
-                    state = False  # Bad boy...
+        for property_name, property_definition in cls.properties.iteritems():
+            if property_name not in special_properties and not hasattr(self, property_name) and property_definition.required:
+                state = False
+                log_configuration_error(self, u'The property %s is not set', property_name)
         
         low_flap = self.low_flap_threshold if self.low_flap_threshold != -1 else self.__class__.global_low_flap_threshold
         high_flap = self.high_flap_threshold if self.high_flap_threshold != -1 else self.__class__.global_high_flap_threshold
         if high_flap < low_flap:
-            logger.error("The service %s on host '%s' have incoherent flap thresholds (respectively low %s%% and high %s%%)" % (desc, hname, low_flap, high_flap))
+            log_configuration_error(self, u'Flapping enter threshold must not be lower than exit threshold (respectively %s%% and %s%%)', low_flap, high_flap)
             state = False
         
         if self.sla_warning_threshold < self.sla_critical_threshold:
-            logger.error("The service %s on host '%s' have incoherent SLA thresholds (respectively critical %s%% and warning %s%%)" % (desc, hname, self.sla_warning_threshold, self.sla_critical_threshold))
+            log_configuration_error(self, u'Critical SLA thresholds must be lower than warning (respectively critical %s%% and warning %s%%)', self.sla_warning_threshold, self.sla_critical_threshold)
             state = False
         
         for custom in self.customs.iterkeys():
-            if self.custom_data_format.search(custom):
-                logger.error("[item::%s] custom property %s is malformed. Special characters are forbidden" % (self.get_name(), custom))
+            if CUSTOM_DATA_FORMAT.search(custom):
+                log_configuration_error(self, u'The DATA name %s is malformed. Special characters are forbidden.', custom)
                 state = False
         
-        # Then look if we have some errors in the conf
-        # Juts print warnings, but raise errors
-        for err in self.configuration_warnings:
-            logger.warning("[service::%s] %s" % (desc, err))
+        for _warning in self.configuration_warnings:
+            log_configuration_warning(self, _warning)
         
         # Raised all previously saw errors like unknown contacts and co
-        if self.configuration_errors != []:
+        if self.configuration_errors:
             state = False
-            for err in self.configuration_errors:
-                logger.error("[service::%s] %s" % (self.get_full_name(), err))
+            for _error in self.configuration_errors:
+                log_configuration_error(self, _error)
         
         # If no notif period, set it to None, mean 24x7
-        if not hasattr(self, 'notification_period'):
+        if not hasattr(self, u'notification_period'):
             self.notification_period = None
         
-        # Set display_name if need
-        if getattr(self, 'display_name', '') == '':
-            self.display_name = getattr(self, 'service_description', '')
+        # We use service_description as display_name is it wasn't set.
+        if getattr(self, u'display_name', u'') == u'':
+            self.display_name = getattr(self, u'service_description', u'')
         
         # If we got an event handler, it should be valid
-        if getattr(self, 'event_handler', None) and not self.event_handler.is_valid():
-            logger.error("%s: my event_handler %s is invalid" % (self.get_name(), self.event_handler.original_command))
+        if getattr(self, u'event_handler', None) and not self.event_handler.is_valid():
+            log_configuration_error(self, u'The event_handler %s is invalid', self.event_handler.get_name())
             state = False
         
         # See SEF-5670 and SEF-4496
-        if not hasattr(self, 'check_command'):
-            if getattr(self, 'active_checks_enabled'):
-                logger.error("%s: I've got no check_command" % self.get_name())
+        if not hasattr(self, u'check_command'):
+            if getattr(self, u'active_checks_enabled'):
+                log_configuration_error(self, u'The check_command is missing')
                 state = False
             else:
                 self.check_command = None
@@ -473,39 +484,40 @@ class Service(SchedulingItem):
         else:
             # Ok got a command, but maybe it's invalid
             if not self.check_command.is_valid():
-                logger.error("%s: my check_command %s is invalid" % (self.get_name(), self.check_command.original_command))
+                log_configuration_error(self, u'The check_command %s is invalid', self.check_command.get_name())
                 state = False
+            
             if self.got_business_rule:
                 if self.business_rule is None:
-                    logger.error("%s: my business rule is invalid" % (self.get_name(),))
+                    log_configuration_error(self, u'The business rule is empty')
                     state = False
                 elif self.business_rule.configuration_errors:
-                    logger.error("%s: my business rule is invalid" % (self.get_name(),))
-                    for bperror in self.business_rule.configuration_errors:
-                        logger.error("%s: %s" % (self.get_name(), bperror))
+                    log_configuration_error(self, u'The business rule is invalid : ')
+                    for bp_error in self.business_rule.configuration_errors:
+                        log_configuration_error(self, u'%s' % bp_error)
                     state = False
         
-        active_mandatory_props = ('retry_interval', 'check_interval')
-        if getattr(self, 'active_checks_enabled') and not self.got_business_rule:
-            for prop in active_mandatory_props:
-                if not hasattr(self, prop):
-                    logger.error("The service %s on host '%s' does not have %s" % (desc, hname, prop))
-                    state = False  # Bad boy...
+        active_mandatory_properties = (u'retry_interval', u'check_interval')
+        if getattr(self, u'active_checks_enabled') and not self.got_business_rule:
+            for property_name in active_mandatory_properties:
+                if not hasattr(self, property_name):
+                    state = False
+                    log_configuration_error(self, u'The property %s is not set', property_name)
         else:
-            for prop in active_mandatory_props:
-                if not hasattr(self, prop):
-                    setattr(self, prop, 1)
+            for property_name in active_mandatory_properties:
+                if not hasattr(self, property_name):
+                    setattr(self, property_name, 1)
         
         if self.host is None:
-            logger.warning("The host_name '%s' for the service '%s' is unknown or disabled." % (self.host_name, desc,))
-            # do not set tis a a true error, only we will delete this after
-        if hasattr(self, 'service_description'):
-            if '$KEY$' in self.service_description:
-                logger.error("%s: Missing duplicate_foreach parameter. Failed to substitute name.")
+            log_configuration_warning(self, u'The host with name %s is unknown or disabled.', self.host_name)
+        
+        if hasattr(self, u'service_description'):
+            if u'$KEY$' in self.service_description:
+                log_configuration_warning(self, u'Missing duplicate_foreach parameter. Failed to substitute name.')
                 return False
-            for c in cls.illegal_object_name_chars:
-                if c in self.service_description:
-                    logger.error("%s: My service_description got the character %s that is not allowed." % (self.get_name(), c))
+            for char in cls.illegal_object_name_chars:
+                if char in self.service_description:
+                    log_configuration_error(self, u'The character %s is not allowed in name.', char)
                     state = False
         return state
     
@@ -609,41 +621,43 @@ class Service(SchedulingItem):
                     new_s.host_uuid = host.uuid
                     if self.is_tpl():  # if template, the new one is not
                         new_s.register = 1
-                    for key in key_value:
-                        dollar_key_string = '$%s$' % key
-                        if key == 'KEY':
-                            if hasattr(self, 'service_description'):
+                    for _dfe_data_name in key_value:
+                        dollar_key_string = u'$%s$' % _dfe_data_name
+                        if hasattr(self, u'service_description'):
+                            if _dfe_data_name == u'KEY':
                                 # We want to change all illegal chars to a _ sign. We can't use class.illegal_obj_char
                                 # because in the "explode" phase, we do not have access to this data! :(
-                                new_s._dfe_key = key_value[key]
+                                new_s.dfe_key_resolved = key_value[_dfe_data_name]
                                 new_s._origin_uuid = self.uuid
-                                safe_key_value = re.sub(r'[' + "`~!$%^&*\"|'<>?,()=" + ']+', '_', key_value[key])
-                                new_s._dfe_original_name_without_key = self.service_description.replace(dollar_key_string, '')
+                                safe_key_value = re.sub(ur'[' + "`~!$%^&*\"|'<>?,()=" + ']+', '_', key_value[_dfe_data_name])
+                                new_s._dfe_original_name_without_key = self.service_description.replace(dollar_key_string, u'')
                                 new_s.service_description = self.service_description.replace(dollar_key_string, safe_key_value)
+                            if _dfe_data_name == u'VALUE' or re.match(u'VALUE\d', _dfe_data_name):
+                                new_s.dfe_value_resolved[_dfe_data_name] = key_value[_dfe_data_name]
                         # Here is a list of property where we will expand the $KEY$ by the value
-                        _the_expandables = ['check_command', 'service_dependencies', 'event_handler']
+                        _the_expandables = [u'check_command', u'service_dependencies', u'event_handler']
                         for prop in _the_expandables:
                             if hasattr(self, prop):
                                 # here we can replace VALUE, VALUE1, VALUE2,...
-                                setattr(new_s, prop, getattr(new_s, prop).replace(dollar_key_string, key_value[key]))
+                                setattr(new_s, prop, getattr(new_s, prop).replace(dollar_key_string, key_value[_dfe_data_name]))
                         # Also loop over service CUSTOM DATA
                         for (custom_key, custom_value) in new_s.customs.iteritems():
                             if dollar_key_string in custom_value:
-                                new_s.customs[custom_key] = custom_value.replace(dollar_key_string, key_value[key])
+                                new_s.customs[custom_key] = custom_value.replace(dollar_key_string, key_value[_dfe_data_name])
                     # s got the same uuid than the source service, it's a problem, so set it's uuid as
                     # a hex about it's service description, the only part quite stable
-                    if hasattr(new_s, 'service_description'):
-                        new_s.uuid = hashlib.md5(new_s.service_description.encode('utf-8')).hexdigest()
+                    if hasattr(new_s, u'service_description'):
+                        new_s.uuid = hashlib.md5(new_s.service_description.encode(u'utf-8')).hexdigest()
                     # And then add in our list this new service
                     duplicates.append(new_s)
             else:
                 # If error, we should link the error to the host, because self is a template, and so won't be checked not print!
                 if errcode == DuplicateForEachStatus.SYNTAX_ERROR:
-                    err = "The custom property '%s' of the host '%s' is not a valid entry %s for a service generator" % (self.duplicate_foreach.strip(), host.get_name(), entry)
+                    err = u'''The custom property '%s' of the host '%s' is not a valid entry %s for a service generator''' % (self.duplicate_foreach.strip(), host.get_name(), entry)
                     logger.warning(err)
                     host.configuration_errors.append(err)
                 elif errcode == DuplicateForEachStatus.NODE_ERROR:
-                    err = "The custom property '%s' of the host '%s' has an invalid node range %s" % (self.duplicate_foreach.strip(), host.get_name(), entry)
+                    err = u'''The custom property '%s' of the host '%s' has an invalid node range %s''' % (self.duplicate_foreach.strip(), host.get_name(), entry)
                     logger.warning(err)
                     host.configuration_errors.append(err)
         return duplicates
@@ -1098,6 +1112,12 @@ class Service(SchedulingItem):
         self.actions.append(e)
     
     
+    # Private key use only in arbiter
+    def get_origin_uuid(self):
+        # type: () -> unicode
+        return self._origin_uuid
+    
+    
     # We want to know the uuid of the definition that did create this check
     # so can be:
     # * genuine check => own uuid
@@ -1401,8 +1421,8 @@ class Services(InheritableItems):
             # NAME => it only have its name, like in duplicate foreach, so we fallback to this
             if name_expr.startswith(PREFIX_LINK_UUID):
                 uuid_to_search, dfe_key = host.parse_service_exclusion_expr(name_expr)
-                link_match_service_without_dfe = (not s._dfe_key and s.uuid == uuid_to_search)
-                link_match_service_with_dfe = (s._dfe_key and s._dfe_key == dfe_key and uuid_to_search == s._origin_uuid)
+                link_match_service_without_dfe = (not s.dfe_key_resolved and s.uuid == uuid_to_search)
+                link_match_service_with_dfe = (s.dfe_key_resolved and s.dfe_key_resolved == dfe_key and uuid_to_search == s._origin_uuid)
                 if s.host_name == host_name and (link_match_service_without_dfe or link_match_service_with_dfe):
                     service = s
                     break
@@ -1533,22 +1553,26 @@ class Services(InheritableItems):
             # If we do not have a host_name, we set it as a template element to delete. (like Nagios)
             if not hasattr(service, 'host_name'):
                 service.host = None
+                err = u'Warning: No host is attached to the services \'%s\'' % (service.get_name())
+                service.configuration_warnings.append(err)
+                continue
+            
+            host_name = service.host_name
+            # The new member list, in id
+            host = hosts.find_by_name(host_name)
+            if not host:
+                err = u'Warning: We do not find the host \'%s\'  attached to the service \'%s\'' % (host_name, service.get_name())
+                service.configuration_warnings.append(err)
+                continue
+            service.host = host
+            service.host_uuid = host.uuid
+            # Let the host know we are his service
+            if service.host is not None:
+                host.add_service_link(service)
+            else:  # Ok, the host do not exist!
+                err = u'Warning: the service \'%s\' got an invalid host_name \'%s\'' % (service.get_name(), host_name)
+                service.configuration_warnings.append(err)
                 continue
-            try:
-                host_name = service.host_name
-                # The new member list, in id
-                host = hosts.find_by_name(host_name)
-                service.host = host
-                service.host_uuid = host.uuid
-                # Let the host know we are his service
-                if service.host is not None:
-                    host.add_service_link(service)
-                else:  # Ok, the host do not exist!
-                    err = u'Warning: the service \'%s\' got an invalid host_name \'%s\'' % (service.get_name(), host_name)
-                    service.configuration_warnings.append(err)
-                    continue
-            except AttributeError as exp:
-                pass  # Will be catch at the is_correct moment
     
     
     # We look for service groups property in services and link them
