@@ -94,6 +94,7 @@ from shinken.daterange import MonthDateDaterange, WeekDayDaterange
 from shinken.daterange import MonthDayDaterange
 from shinken.daterange import StandardDaterange, MonthWeekDayDaterange
 from shinken.log import logger, naglog_result
+from shinken.misc.configuration_error_log import log_configuration_error, log_configuration_warning
 from shinken.misc.type_hint import TYPE_CHECKING
 from shinken.property import IntegerProp, StringProp, ListProp, BoolProp
 from shinkensolutions.time_period_parser import TimePeriodParser
@@ -424,28 +425,29 @@ class Timeperiod(Item):
     # We are correct only if our daterange are
     # and if we have no unmatch entries
     def is_correct(self):
-        b = True
+        # type: () -> bool
+        state = True
         
         for tp in self.exclude:
             if tp.get_uuid() == self.get_uuid():
-                b = False
-                logger.error("[timeperiod::%s] invalid exclude value, it cannot exclude itself " % (self.get_link_shinken()))
-
-        for dr in self.dateranges:
-            d = dr.is_correct()
-            if not d:
-                logger.error("[timeperiod::%s] invalid daterange " % (self.get_name()))
-            b &= d
+                log_configuration_error(self, u'invalid exclude value, it cannot exclude itself')
+                state = False
+        
+        for daterange in self.dateranges:
+            if not daterange.is_correct():
+                log_configuration_error(self, u'invalid daterange')
+                state = False
+        
+        # Warn about non-correct entries
+        for _entry in self.invalid_entries:
+            log_configuration_warning(self, u'invalid entry : %s', _entry)
         
-        # Warn about non correct entries
-        for e in self.invalid_entries:
-            logger.warning("[timeperiod::%s] invalid entry '%s'" % (self.get_name(), e))
-
         if self.configuration_errors:
-            for err in self.configuration_errors:
-                logger.error("[timeperiod] %s" % err)
-            return False
-        return b
+            for error in self.configuration_errors:
+                log_configuration_error(self, error)
+                state = False
+        
+        return state
     
     
     def __str__(self):
@@ -739,6 +741,7 @@ class Timeperiods(Items):
     
     # check for loop in definition
     def is_correct(self):
+        # type: () -> bool
         r = True
         # We do not want a same hg to be explode again and again
         # so we tag it
