@@ -57,12 +57,14 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                 break;
             case "00082":
                 //LIST HOST WORKING AREA
-                if ( MANAGER.__instance_element_distributor.current_user.uuid !== '35000000000000000000000000000000' ) {
-                    SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
-                    alert("test_auto_user_executor pas défini ==> relancer le test");
-                }
+
                 switch ( __phase ) {
                     case 1:
+                        if ( MANAGER.__instance_element_distributor.current_user.uuid !== '35000000000000000000000000000000' ) {
+                            SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
+                        }
+                        break;
+                    case 2:
                         //STRUCTURE ET SELECTOR
                         _mass_action_selector = document.getElementById( "id-shinken-select-mass-action" );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasData( _timeout, document.getElementById( "page-list" ), 'isAdmin', 'True', 'data body is-admin' ) );
@@ -86,18 +88,17 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ), "option mass action specifique stagging" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-staging' ).querySelector( '.shinken-optgroup-title' ), "#id-shinken-actions-host-staging .shinken-optgroup-title" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
-                        break;
-                    case 2:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                         break;
                     case 3:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-3' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                         break;
                     case 4:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-4' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
+                        break;
+                    case 5:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-5' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectMassAction( _timeout, ACTIONS.DISABLE ) );
@@ -106,7 +107,7 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                         __do_next = false;
                         break;
-                    case 5:
+                    case 6:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
@@ -117,11 +118,11 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                         __do_next = false;
                         break;
-                    case 6:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-6' ) );
+                    case 7:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout, '00082-7' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                         break;
-                    case 7:
+                    case 8:
                         _mass_action_selector = document.getElementById( "id-shinken-select-mass-action" );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
@@ -133,7 +134,7 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
                         break;
-                    case 8:
+                    case 9:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
@@ -141,7 +142,7 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                         __do_next = false;
                         break;
-                    case 9:
+                    case 10:
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.selectShinkenElement( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.massActionsOptions( _timeout, 13 ) );
@@ -149,8 +150,6 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.clickOnExecuteMassAction( _timeout ) );
                         __do_next = false;
                         break;
-                    case 10:
-                        break;
                 }
                 break;
             case "00083":
@@ -239,7 +238,7 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch" ), "shinken-disabled", false, "bouton exécuter" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasClass( _timeout, document.getElementById( "btn-action-launch-add-comment" ), "shinken-disabled", false, "bouton exécuter comment" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isText( _timeout, _mass_action_selector.querySelector( ".shinken-select-selector" ), "", "text du selecteur de mass action" ) );
-                
+                        
                         ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.switchMassActionSelectorState( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, _mass_action_selector.querySelector( '.shinken-list-select' ), "options mass action" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, document.getElementById( 'id-shinken-actions-host-working-area' ), "option mass action specifique working area" ) );
@@ -446,17 +445,17 @@ SHINKEN.TOOLS.TEST_AUTO_LIST_RUN = (function ( self ) {
                         break;
                 }
                 break;
-    
+            
             case "00184":
                 switch ( __phase ) {
                     case 1:
                         ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_admin_si", "test_auto_admin_si" ) );
                         break;
                     case 2:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.do_mass_action_without_UI( _timeout, [403], SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.CONST.MASS_CHANGE_ACTION_IMPORT , "1") );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.do_mass_action_without_UI( _timeout, [403], SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.CONST.MASS_CHANGE_ACTION_IMPORT, "1" ) );
                         break;
                     case 3:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.do_mass_action_without_UI( _timeout, [403], SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.CONST.MASS_CHANGE_ACTION_DIFFERENCE , "1") );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.do_mass_action_without_UI( _timeout, [403], SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.CONST.MASS_CHANGE_ACTION_DIFFERENCE, "1" ) );
                         break;
                     case 4:
                         ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
