@@ -53,23 +53,32 @@ SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN = (function ( self ) {
                 ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                 break;
             case "00070":
-                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
-                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
-                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
-                _current_property = PROPERTY.CONST.NAME.USE;
                 switch ( __phase ) {
                     case 1:
+                        ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone(_timeout, true) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "duplicated_accepted" ) );
                         break;
+                    case 2:
                     case 3:
+                        _current_property = PROPERTY.CONST.NAME.USE;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, _current_property, 'ADD_BEFORE' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
+                        break;
                     case 4:
+                    case 5:
                         _current_property = PROPERTY.CONST.NAME.HOSTGROUPS;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, _current_property, 'ADD_BEFORE' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                         break;
                 }
-                ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone(_timeout, true) );
-                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, _current_property, 'ADD_BEFORE' ) );
-                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
-                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                 break;
             case "00071":
                 ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
@@ -152,7 +161,7 @@ SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN = (function ( self ) {
                 ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                 break;
             case "00092":
-                if ( __version_shinken <= "Vxx.xx.xx" ) {
+                if ( __version_shinken !== SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.UNKNOWN ) {
                     console.error( "[TEST AUTO]", "[TEST ABORT]" ,"WAITING FOR DEV LEO" );
                     break;
                 }
@@ -162,7 +171,7 @@ SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN = (function ( self ) {
                 ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTILINE.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.NOTE_MULTI_URL ) );
                 break;
             case "00093":
-                if ( __version_shinken <= "Vxx.xx.xx" ) {
+                if ( __version_shinken !== SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.UNKNOWN ) {
                     console.error( "[TEST AUTO]", "[TEST ABORT]" ,"WAITING FOR DEV LEO" );
                     break;
                 }
@@ -227,34 +236,34 @@ SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN = (function ( self ) {
                     case 2:
                     case 3:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 4:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 5:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 6:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 7:
                     case 8:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REPLACE ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_PLUS, PROPERTY.CONST.MASS_CHANGE.PLUS_ACTION.OFF ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ELEMENT_SINGLE, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ELEMENT_EXTRA, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ELEMENT_SINGLE, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ELEMENT_EXTRA, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                         _timeout += 2000;
                         break;
                     case 9:
@@ -262,11 +271,11 @@ SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN = (function ( self ) {
                     case 11:
                     case 12:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                         break;
                     case 13:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                         break;
                     case 14:
                     case 15:
@@ -286,40 +295,40 @@ SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN = (function ( self ) {
                         break;
                     case 21:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 22:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 23:
                     case 24:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_PLUS, PROPERTY.CONST.MASS_CHANGE.PLUS_ACTION.ON ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 25:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                         break;
                     case 26:
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                         break;
                     case 27:
                         ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.GENERIC ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.USE, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.HOSTTPLS.TEST_AUTO_VALID_WITH_USER_RIGHTS_1.DATA[ 'name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.USE, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.HOSTTPLS.TEST_AUTO_VALID_WITH_USER_RIGHTS_1.DATA[ 'name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_EXTRA, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.LAST ) );
                         break;
                     case 28:
                         ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.GENERIC ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.USE, SHINKEN.TOOLS.TEST_AUTO.CONST.DEFAULT_CONFIG_TEST_AUTO_VALID.HOSTTPLS.TEST_AUTO_VALID_WITH_USER_RIGHTS_4.DATA[ 'name' ] ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.USE, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.HOSTTPLS.TEST_AUTO_VALID_WITH_USER_RIGHTS_4.DATA[ 'name' ] ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_EXTRA, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.LAST ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
