@@ -35,6 +35,9 @@ SHINKEN.TOOLS.TEST_AUTO_PROPERTY = (function ( self ) {
     self.DOM.defaultButton                     = function ( property_name ) {
         return self.DOM.line( property_name ).querySelector( '.shinken-range-btn-default-container .shinken-radio-btn' );
     };
+    self.DOM.noOverrideButton                     = function ( property_name ) {
+        return self.DOM.line( property_name ).querySelector( '.shinken-no-override-btn' );
+    };
     self.DOM.inheritanceButton                 = function ( property_name ) {
         return self.DOM.line( property_name ).querySelector( '.shinken-prop-cell-template .switch-button-wrapper' );
     };
@@ -67,6 +70,9 @@ SHINKEN.TOOLS.TEST_AUTO_PROPERTY = (function ( self ) {
     self.DOM.flatCheckValue                    = function ( property_override_name ) {
         return self.DOM.line( property_override_name ).querySelector( '.shinken-flat-check-value' );
     };
+    self.DOM.extraLabelPropertyName            = function ( property_name ) {
+        return self.DOM.line( property_name ).querySelector( '.shinken-property-label .shinken-extra-label' );
+    };
     //********************************************  ACTION VIA JS OBJECT   **************************************************//
     self.ACTION.selectOptionInPropertySelector = function ( timeout, property_name, selector_name, option_name ) {
         setTimeout( function () {
@@ -99,6 +105,12 @@ SHINKEN.TOOLS.TEST_AUTO_PROPERTY = (function ( self ) {
         }, timeout );
         return 500;
     };
+    self.ACTION.clickOnNoOverrideButton           = function ( timeout, property_name ) {
+        setTimeout( function () {
+            self.DOM.noOverrideButton( property_name ).click();
+        }, timeout );
+        return 500;
+    };
     self.ACTION.clickOnRadioButton             = function ( timeout, property_name, button_name ) {
         setTimeout( function () {
             self.DOM.radioBtnContainer( property_name ).querySelector( '.shinken-button[value="' + button_name + '"]' ).click();
@@ -176,7 +188,7 @@ SHINKEN.TOOLS.TEST_AUTO_PROPERTY = (function ( self ) {
         return 100;
     };
     self.TEST.countWindow                      = function ( timeout, number_expected ) {
-        if ( __version_shinken === "V02.07.06" ){
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA ){
             return 0
         }
         setTimeout( function () {
@@ -247,6 +259,9 @@ SHINKEN.TOOLS.TEST_AUTO_PROPERTY = (function ( self ) {
         return 10;
     };
     self.TEST.linkButton                       = function ( timeout, property_name, state, uuid_link ) {
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
+            return 0
+        }
         setTimeout( function () {
             var _dom_link_button = self.DOM.linkButton( property_name );
             var _dom_link        = _dom_link_button.querySelector( ".shinken-link" );
@@ -339,6 +354,14 @@ SHINKEN.TOOLS.TEST_AUTO_PROPERTY = (function ( self ) {
         }, timeout );
         return 10;
     };
+    self.TEST.extraLabelPropertyName           = function ( timeout, property_name ) {
+        setTimeout( function () {
+            if ( __version_shinken !== SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
+                SHINKEN.TOOLS.TEST_AUTO.__isInnerTextEqualTo( self.DOM.extraLabelPropertyName( property_name ), _( "extra_label." + property_name ), "PROPERTY EXTRA_LABEL" );
+            }
+        }, timeout );
+        return 10;
+    };
     //********************************************  ACTION   **************************************************//
     return self;
 })( SHINKEN.TOOLS.TEST_AUTO_PROPERTY || {} );
