@@ -1,5 +1,5 @@
 SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
-    var _timeout = 0;
+    var _timeout     = 0;
     var _widget_type = null;
     
     function ____ ( fct ) {
@@ -53,7 +53,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED_AND_NO_EVENT ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 1 ) );
@@ -73,11 +73,11 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_back_to_previous_preview" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 3 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED_AND_NO_EVENT ) );
                         break;
                     case 5:
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_external_links', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_external_links', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED_AND_NO_EVENT ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'popup_external_links', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
@@ -88,7 +88,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         break;
                 }
                 break;
-            case "00175":
+            case "00175": //MESSAGE D ERREUR ET WARNING
                 switch ( __phase ) {
                     case 1:
                         //TEST: height
@@ -119,7 +119,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         //TEST: position y
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [ 130, 140, 150 ], 3 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [130, 140, 150], 3 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, ["0", "10", "20"], 0, 0, 0, 3 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [0, 10, 20] ) );
                         break;
@@ -127,7 +127,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         //TEST: type   // a débug une fois que le bug 29) aura été réglé FGAR
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 4, 0, 3 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1, 4, 0, 3 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [ "title_widget", "title_widget", "weather_widget" ], 1 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, ["title_widget", "title_widget", "weather_widget"], 1 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, ["title_widget", "separator_widget", "weather_widget"] ) );
                         break;
                     case 6:
@@ -139,7 +139,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                     case 7:
                     case 32:
                         //text_color
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "#ff0000;",  2  ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "#ff0000;", 2 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "#FF0000" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "rgb(252, 186, 3)" ) );
@@ -314,7 +314,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                     case 40:
                         //external_links links__default_base_url
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 2 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "test_auto/test_auto", 1 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "test_auto/test_auto", 2 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "test_auto" ) );
                         break;
                     case 34:
@@ -352,7 +352,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                     case 38:
                         //links link_name
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "", 1 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "default" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "test_auto" ) );
                         break;
@@ -373,6 +373,17 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, EXTERNAL_LINKS.CONST.EXTERNAL_LINK.ENUM.LINK_PROTOCOL.HTTPS ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, EXTERNAL_LINKS.CONST.EXTERNAL_LINK.ENUM.LINK_PROTOCOL.HTTP ) );
                         break;
+                    case 45:
+                    case 46:
+                    case 47:
+                        //notifications
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 2 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 12, 2, 0, 2 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "Toto", 2, 0, 2 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False", 0, 0, 0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false", 0, 0, 0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 0, 0, 0 ) );
+                        break;
                 }
                 break;
             case "00176":
@@ -380,10 +391,10 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                     case 1:
                         //TEST WARNING DISPLAYED AFTER SAVE AND RELOAD
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.countProblems( _timeout, 0, 1 , false) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.countProblemsInWindow( _timeout, 0, 1, false ) );
                         break;
                     case 2:
                         break;
@@ -418,10 +429,10 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 10, 0, 6 ) );
                         break;
                     case 5:
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 4, 0 , 4 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 4, 0, 4 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 4 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 4) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 4) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 4 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 4 ) );
                         break;
                 }
                 break;
@@ -449,7 +460,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.LEFT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.RIGHT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
-    
+                        
                         // LEFT AREA: displayed:true - width: 0 | RIGHT AREA: displayed:true - width: 20
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 3 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
@@ -468,6 +479,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.LEFT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.RIGHT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                         break;
+                    
                     case 2:
                         // TODO TESTER NOIR AVANT
                         // TITLE AREA: color:"red"
@@ -475,22 +487,22 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_mode_edit" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textColor( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, "rgb(255, 0, 0)") );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textColor( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, "rgb(255, 0, 0)" ) );
                         break;
                     case 3:  //TEST: WidgetSeparator text align
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_mode_edit" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign(  _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.CENTER));
-                       
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.CENTER ) );
+                        
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 2 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign(  _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.LEFT));
-
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.LEFT ) );
+                        
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 3 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign(  _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.RIGHT));
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.RIGHT ) );
                         break;
                 }
                 break;
@@ -607,57 +619,220 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
             case "00217":
                 switch ( __phase ) {
                     case 1:
-                        _timeout +=  SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
+                        _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                         break;
                     case 2:
+                        ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone( _timeout ) );
+                        break;
+                    case 3:
                         ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.ELEMENT_VISIBILITY_ON_NOT_AUTHENTICATED_VIEW, "1" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
                         break;
-                    case 4:
+                    case 5:
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 4, 0, 0 ) );
                         break;
-                    case 5:
+                    case 6:
                         _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" );
                         break;
-                    case 6:
+                    case 7:
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 4, 0, 0 ) );
                         break;
-                    case 7:
+                    case 8:
                         _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                         break;
-                    case 8:
+                    case 9:
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.ELEMENT_VISIBILITY_ON_NOT_AUTHENTICATED_VIEW, "1" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
                         break;
-                    case 10:
+                    case 11:
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 4, 0, 2 ) );
                         break;
-                    case 11:
+                    case 12:
                         _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" );
                         break;
-                    case 12:
+                    case 13:
                         ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2, 0, 0 ) );
                         break;
-                    case 13:
+                    case 14:
                         _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                         break;
-                        
+                    
                 }
                 break;
             case "00219":
-                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.open(_timeout, "/service-weather/no_existing") );
-                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.TEST.pathName(_timeout, "/service-weather-not-found/no_existing") );
-                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close(_timeout ));
+                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.open( _timeout, "/service-weather/no_existing" ) );
+                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.TEST.pathName( _timeout, "/service-weather-not-found/no_existing" ) );
+                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
+                break;
+            case "00231":
+                switch ( __phase ) {
+                    case 1:
+                        // ALL TRUE
+                        _timeout += 2000;
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 90 ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", true, true ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_external_links' ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'popup_external_links' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.mouseEnterLink( _timeout, "002311" ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.EXTERNAL_LINKS.tooltipOfLinkContainsText( _timeout, "Son : Activé", true  ) );
+                        
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "OFF" ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 0 ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", true, true ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED ) );
+                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_CHILDREN_DISABLED ) );
+                        __do_next = false;
+                        break;
+                    case 2:
+                        _timeout += 2000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "OFF" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 50 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        break;
+                    case 3:
+                        _timeout += 2000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "OFF" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 50 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
+                        break;
+                }
+                break;
+            case "00234":
+                switch ( __phase ) {
+                    case 1:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 90 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
+                        break;
+                    case 2:
+                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "1" et "1";
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
+                            1 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
+                            1 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
+                        break;
+                    case 3:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
+                        break;
+                    case 4:
+                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "0" et "1";
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
+                            0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
+                            1 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
+                        break;
+                    case 5:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
+                        break;
+                    case 6:
+                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "1" et "0";
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
+                            1 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
+                            0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
+                        break;
+                    case 7:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        break;
+                    case 8:
+                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "0" et "0";
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
+                            0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
+                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
+                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
+                            0 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
+                        break;
+                    case 9:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
+                        break;
+                }
                 break;
             default:
                 ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN.do( _timeout ) );
