@@ -4,6 +4,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
     self.TEST.JS                                = {};
     self.ACTION                                 = {};
     self.ACTION.IFRAME                          = {};
+    self.TEST.EXTERNAL_LINKS                    = {};
     self.STATUS_LINE_NUMBER                     = {
         STATE_DISPLAY: {
             OK     : 0,
@@ -19,6 +20,10 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         var _document = in_iframe ? SHINKEN.TOOLS.TEST_AUTO_WEATHER.DOM.IFRAME.getIframe() : document;
         return _document.querySelector( ".shinken-weather-form-container" );
     };
+    self.DOM.getTooltip                         = function ( in_iframe ) {
+        var _document = in_iframe ? SHINKEN.TOOLS.TEST_AUTO_WEATHER.DOM.IFRAME.getIframe() : document;
+        return _document.getElementById( "shi-tip" );
+    };
     self.DOM.modeEditButton                     = function ( in_iframe ) {
         return self.DOM.editButtonsContainer( in_iframe ).querySelector( '.shinken-button[data-name="enter_in_edit_mode"]' );
     };
@@ -89,10 +94,16 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
                 return self.DOM.toggleDisplayOfWidgetsIssuesButton( in_iframe );
         }
     };
+    self.DOM.getExternalLinks                   = function ( in_iframe ) {
+        return self.DOM.editButtonsContainer( in_iframe ).querySelector( '.shinken-external-links-table' );
+    };
+    self.DOM.getExternalLinkByUUID              = function ( in_iframe, link_uuid ) {
+        return self.DOM.getExternalLinks( in_iframe ).querySelector( '.shinken-external-link-row[data-link-uuid="' + link_uuid + '"]' );
+    };
     //********************************************  GETTER   **************************************************//
     
     //********************************************  TEST   **************************************************//
-    self.TEST.validationCase         = function ( timeout, value_to_test, nb_errors_window, nb_warnings_window, nb_errors_json, nb_warnings_json ) {
+    self.TEST.validationCase                           = function ( timeout, value_to_test, nb_errors_window, nb_warnings_window, nb_errors_json, nb_warnings_json ) {
         var _to_return     = 15000;
         nb_errors_window   = nb_errors_window || 0;
         nb_warnings_window = nb_warnings_window || 0;
@@ -115,7 +126,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.TEST.validationJsonInvalid  = function ( timeout, comma_index_removed, line_error_number ) {
+    self.TEST.validationJsonInvalid                    = function ( timeout, comma_index_removed, line_error_number ) {
         var _to_return = 2000 + 1000 + 2000 + 400;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "validationCase", comma_index_removed + " - " + line_error_number );
         setTimeout( function () {
@@ -132,7 +143,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.TEST.lineNumberStatus       = function ( timeout, line_error_number, status_to_test ) {
+    self.TEST.lineNumberStatus                         = function ( timeout, line_error_number, status_to_test ) {
         var _to_return = 400;
         setTimeout( function () {
             var _dom = self.DOM.getLineNumber( line_error_number );
@@ -144,7 +155,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.TEST.countProblemsInWindow  = function ( timeout, nb_errors_expected, nb_warnings_expected, skip_visibility_test ) {
+    self.TEST.countProblemsInWindow                    = function ( timeout, nb_errors_expected, nb_warnings_expected, skip_visibility_test ) {
         var _to_return = 200;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "countProblemsInWindow" );
         setTimeout( function () {
@@ -160,7 +171,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.TEST.countProblemsInJson    = function ( timeout, nb_errors_expected, nb_warnings_expected ) {
+    self.TEST.countProblemsInJson                      = function ( timeout, nb_errors_expected, nb_warnings_expected ) {
         var _to_return = 200;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "countProblemsInJson" );
         setTimeout( function () {
@@ -170,8 +181,19 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
+    self.TEST.EXTERNAL_LINKS.tooltipOfLinkContainsText = function ( timeout, text, in_iframe ) {
+        var _to_return = 500;
+        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'TEST.EXTERNAL_LINKS.tooltipOfLinkContainsText' );
+        setTimeout( function () {
+            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
+            var _dom_element = DOM.Service.createElement( "div", {}, text );
+            SHINKEN.TOOLS.TEST_AUTO.__isInnerTextContains( self.DOM.getTooltip( in_iframe ), _dom_element, "text dans le tooltip" );
+            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
+        }, timeout );
+        return _to_return;
+    };
     //********************************************  ACTION   **************************************************//
-    self.ACTION.resetJSON            = function ( timeout ) {
+    self.ACTION.resetJSON                              = function ( timeout ) {
         var _to_return = 11000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "reset", "" );
         setTimeout( function () {
@@ -182,7 +204,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.ACTION.clickOnButton        = function ( timeout, button_name, in_iframe ) {
+    self.ACTION.clickOnButton                          = function ( timeout, button_name, in_iframe ) {
         var _to_return = 3000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "clickOnButton", button_name );
         setTimeout( function () {
@@ -193,21 +215,24 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.ACTION.IFRAME.clickOnButton = function ( timeout, button_name ) {
+    self.ACTION.IFRAME.clickOnButton                   = function ( timeout, button_name ) {
         return self.ACTION.clickOnButton( timeout, button_name, true );
     };
-    self.ACTION.setJSONInForm        = function ( timeout, extra_step, is_reset, info, value_to_force ) {
+    self.ACTION.setJSONInForm                          = function ( timeout, extra_step, is_reset, info, value_to_force, in_iframe ) {
         var _to_return = 1000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "setJSONInForm", info );
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
-            var _dom_textarea       = self.DOM.formTextArea();
+            var _dom_textarea       = self.DOM.formTextArea( in_iframe );
             _dom_textarea.innerText = JSON.stringify( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON.GETTER.template( extra_step, is_reset, value_to_force ) );
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
         }, timeout );
         return _to_return;
     };
-    self.ACTION.IFRAME.setJSONInForm = function ( timeout, name_title, user_name ) {
+    self.ACTION.IFRAME.setJSONInForm                   = function ( timeout, extra_step, is_reset, info, value_to_force ) {
+        return self.ACTION.setJSONInForm( timeout, extra_step, is_reset, info, value_to_force, true );
+    };
+    self.ACTION.IFRAME.createJSONInForm                = function ( timeout, name_title, user_name ) {
         var _to_return = 1000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "setJSONInForm2", name_title );
         setTimeout( function () {
@@ -218,7 +243,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.ACTION.setJSONInvalidInForm = function ( timeout, index_comma_to_remove ) {
+    self.ACTION.setJSONInvalidInForm                   = function ( timeout, index_comma_to_remove ) {
         var _to_return = 1000;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, "setJSONInForm", "TEST MISSING COMMA" );
         setTimeout( function () {
@@ -230,6 +255,15 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT      = (function ( self ) {
         }, timeout );
         return _to_return;
     };
+    self.ACTION.mouseEnterLink                         = function ( timeout, link_uuid, in_iframe ) {
+        setTimeout( function () {
+            SHINKEN.TOOLS.TEST_AUTO.dispatchMouseEvent( timeout, self.DOM.getExternalLinkByUUID( in_iframe, link_uuid ), 'mouseenter' );
+        }, timeout );
+        return 5000;
+    };
+    self.ACTION.IFRAME.mouseEnterLink                  = function ( timeout, link_uuid ) {
+        return self.ACTION.mouseEnterLink( timeout, link_uuid, true );
+    };
     //********************************************  CONSTANT **************************************************//
     return self;
 })( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT || {} );
@@ -528,6 +562,19 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
             case "00175-44":
                 _to_return[ "external_links" ][ "default_link" ][ "link_protocol" ] = value_to_force;
                 break;
+            case "00175-45":
+                _to_return[ "notifications" ][ "sound" ][ "enabled" ]             = value_to_force;
+                _to_return[ "notifications" ][ "visual" ][ "blink" ][ "enabled" ] = value_to_force;
+                break;
+            case "00175-46":
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "sound" ][ "enabled" ]             = value_to_force;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ] = value_to_force;
+                break;
+            case "00175-47":
+                _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
+                _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ][ "sound" ][ "enabled" ]             = value_to_force;
+                _to_return[ "external_links" ][ "links" ][ 0 ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ] = value_to_force;
+                break;
             case "00176-1":
                 _to_return[ "grids" ][ 0 ][ "grid_elements" ][ 0 ][ "content" ][ "layout" ][ "information_to_display" ][ "title_area" ][ "labelss" ] = "test_auto";
                 break;
@@ -679,7 +726,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
             case "00209-1-1":
                 _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
                 break;
-            case "00217-4":
+            case "00217-5":
                 _to_return[ "grids" ][ 0 ][ "grid_elements" ].push( {
                     "position_x": 15,
                     "position_y": 6,
@@ -697,7 +744,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
                 _to_return[ "external_links" ][ "links" ][ 0 ][ "authentication_needed" ] = true;
                 _to_return[ "external_links" ][ "links" ][ 0 ][ "info_bar" ]              = {};
                 break;
-            case "00217-10":
+            case "00217-11":
                 _to_return[ "grids" ][ 0 ][ "grid_elements" ].push( {
                     "position_x": 15,
                     "position_y": 6,
@@ -715,6 +762,47 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
                 _to_return[ "external_links" ][ "links" ][ 0 ][ "authentication_needed" ] = false;
                 _to_return[ "external_links" ][ "links" ][ 0 ][ "info_bar" ]              = {};
                 break;
+            case "00231-1":
+                _to_return[ "grids" ][ 0 ][ "grid_elements" ][ 0 ][ "content" ][ "layout" ][ "information_to_display" ][ "title_area" ][ "label" ] = "TEST-AUTO-00231";
+                _to_return[ "notifications" ][ "sound" ][ "enabled" ]                                                                              = true;
+                _to_return[ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                                                                  = true;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "sound" ][ "enabled" ]                                        = true;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                            = true;
+                _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
+                _to_return[ "external_links" ][ "links" ][ 0 ][ "link_uuid" ] = "002311";
+                break;
+            case "00231-2":
+                _to_return[ "grids" ][ 0 ][ "grid_elements" ][ 0 ][ "content" ][ "layout" ][ "information_to_display" ][ "title_area" ][ "label" ] = "TEST-AUTO-00231";
+                _to_return[ "notifications" ][ "sound" ][ "enabled" ]                                                                              = false;
+                _to_return[ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                                                                  = false;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "sound" ][ "enabled" ]                                        = false;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                            = false;
+                _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
+                break;
+            case "00231-3":
+                _to_return[ "grids" ][ 0 ][ "grid_elements" ][ 0 ][ "content" ][ "layout" ][ "information_to_display" ][ "title_area" ][ "label" ] = "TEST-AUTO-00231";
+                _to_return[ "notifications" ][ "sound" ][ "enabled" ]                                                                              = false;
+                _to_return[ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                                                                  = false;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "sound" ][ "enabled" ]                                        = false;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                            = false;
+                _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
+                break;
+            case "00231-4":
+                _to_return[ "grids" ][ 0 ][ "grid_elements" ][ 0 ][ "content" ][ "layout" ][ "information_to_display" ][ "title_area" ][ "label" ] = "TEST-AUTO-00231";
+                _to_return[ "notifications" ][ "sound" ][ "enabled" ]                                                                              = false;
+                _to_return[ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                                                                  = false;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "sound" ][ "enabled" ]                                        = true;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                            = true;
+                _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
+                break;
+            case "00231-5":
+                _to_return[ "grids" ][ 0 ][ "grid_elements" ][ 0 ][ "content" ][ "layout" ][ "information_to_display" ][ "title_area" ][ "label" ] = "TEST-AUTO-00231";
+                _to_return[ "notifications" ][ "sound" ][ "enabled" ]                                                                              = false;
+                _to_return[ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                                                                  = false;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "sound" ][ "enabled" ]                                        = false;
+                _to_return[ "external_links" ][ "default_link" ][ "notifications" ][ "visual" ][ "blink" ][ "enabled" ]                            = false;
+                _to_return[ "external_links" ][ "links" ].push( { "link_name": "test_auto" } );
+                break;
             
         }
         return _to_return;
@@ -755,10 +843,31 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
         ],
         "external_links": {
             "default_link": {
-                "info_bar": {
+                "info_bar"     : {
                     "refresh": {}
+                },
+                "notifications": {
+                    "sound" : {
+                        "enabled": "default"
+                    },
+                    "visual": {
+                        "blink": {
+                            "enabled": "default"
+                        }
+                    }
                 }
             }, "links"    : []
+            
+        },
+        "notifications" : {
+            "sound" : {
+                "enabled": "default"
+            },
+            "visual": {
+                "blink": {
+                    "enabled": "default"
+                }
+            }
         }
     };
     self.TEMPLATE_2                = {
@@ -855,8 +964,18 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
         ],
         "external_links": {
             "default_link": {
-                "info_bar": {
+                "info_bar"     : {
                     "refresh": {}
+                },
+                "notifications": {
+                    "sound" : {
+                        "enabled": "default"
+                    },
+                    "visual": {
+                        "blink": {
+                            "enabled": "default"
+                        }
+                    }
                 }
             },
             "links"       : []
@@ -865,6 +984,18 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT_JSON = (function ( self ) {
             "owner_user": {
                 "user_uuid": "35000000000000000000000000000000"
             }
+        },
+        "notifications" : {
+            
+            "sound" : {
+                "enabled": "default"
+            },
+            "visual": {
+                "blink": {
+                    "enabled": "default"
+                }
+            }
+            
         }
     };
     self.TEMPLATE_SEPARATOR_WIDGET = {
