@@ -2,15 +2,19 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
     self.DOM                              = {};
     self.DOM.IFRAME                       = {};
     self.TEST                             = {};
+    self.TEST.IFRAME                      = {};
     self.TEST.WIDGET                      = {};
     self.TEST.WEATHER_GRID_CELL           = {};
     self.TEST.JS                          = {};
     self.ACTION                           = {};
     self.CONST                            = {
         STATE_DISPLAY    : {
-            HIDDEN              : 0,
-            VISIBLE             : 1,
-            VISIBLE_AND_DISABLED: 2
+            HIDDEN                           : 0,
+            VISIBLE                          : 1,
+            VISIBLE_AND_DISABLED             : 2,
+            VISIBLE_AND_CHILDREN_DISABLED    : 3,
+            VISIBLE_AND_DISABLED_AND_NO_EVENT: 4
+            
         },
         WEATHER_GRID_CELL: {
             STATE: {
@@ -38,31 +42,41 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
     self.DOM.pageContainer                = function ( in_iframe ) {
         return in_iframe ? self.DOM.IFRAME.getIframe().getElementById( 'id-shinken-page-container' ) : document.getElementById( 'id-shinken-page-container' );
     };
-    self.DOM.infoBar                      = function () {
-        return self.DOM.pageContainer().querySelector( '.shinken-info-bar' );
+    self.DOM.infoBar                      = function ( in_iframe ) {
+        return self.DOM.pageContainer( in_iframe ).querySelector( '.shinken-info-bar' );
     };
-    self.DOM.infoBarShinkenLogo           = function () {
-        return self.DOM.infoBar().querySelector( '.shinken-logo' );
+    self.DOM.infoBarShinkenLogo           = function ( in_iframe ) {
+        return self.DOM.infoBar( in_iframe ).querySelector( '.shinken-logo' );
     };
-    self.DOM.infoBarGenerateAt            = function () {
-        return self.DOM.infoBar().querySelector( '.shinken-generate-at' );
+    self.DOM.infoBarGenerateAt            = function ( in_iframe ) {
+        return self.DOM.infoBar( in_iframe ).querySelector( '.shinken-generate-at' );
     };
-    self.DOM.infoBarTimer                 = function () {
-        return self.DOM.infoBar().querySelector( '.shinken-container-clock' );
+    self.DOM.infoBarTimer                 = function ( in_iframe ) {
+        return self.DOM.infoBar( in_iframe ).querySelector( '.shinken-container-clock' );
     };
-    self.DOM.getElement                   = function ( type_element ) {
+    self.DOM.infoBarSoundNotification     = function ( in_iframe ) {
+        return self.DOM.infoBar( in_iframe ).querySelector( '.shinken-sound-notification-container' );
+    };
+    self.DOM.infoBarBlinkNotification     = function ( in_iframe ) {
+        return self.DOM.infoBar( in_iframe ).querySelector( '.shinken-blink-notification-container' );
+    };
+    self.DOM.getElement                   = function ( type_element, in_iframe ) {
         switch ( type_element ) {
             case 'button_mode_edit':
             case 'button_back_to_previous_preview':
             case 'button_external_links':
             case 'popup_external_links':
-                return SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.DOM.getElement( type_element );
+                return SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.DOM.getElement( type_element, in_iframe );
             case 'logo_shinken':
-                return self.DOM.infoBarShinkenLogo();
+                return self.DOM.infoBarShinkenLogo( in_iframe );
             case 'generate_at':
-                return self.DOM.infoBarGenerateAt();
+                return self.DOM.infoBarGenerateAt( in_iframe );
             case 'timer_icon':
-                return self.DOM.infoBarTimer();
+                return self.DOM.infoBarTimer( in_iframe );
+            case 'sound_notification_container':
+                return self.DOM.infoBarSoundNotification( in_iframe );
+            case 'blink_notification_container':
+                return self.DOM.infoBarBlinkNotification( in_iframe );
         }
     };
     self.DOM.getAllWidgets                = function () {
@@ -112,6 +126,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
     };
     
     
+    
     //self.DOM.getWidgetTitleTitleArea       = function () {
     //    return self.DOM.getWidgetTitle().querySelector(".shinken-widget-title-content");
     //};
@@ -122,12 +137,12 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
     //********************************************  GETTER   **************************************************//
     
     //********************************************  TEST   **************************************************//
-    self.TEST.displayState            = function ( timeout, type_element, state ) {
+    self.TEST.displayState            = function ( timeout, type_element, state, in_iframe ) {
         var _to_return = 50;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'TEST.displayState', state, type_element );
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
-            var _dom = self.DOM.getElement( type_element );
+            var _dom = self.DOM.getElement( type_element, in_iframe );
             switch ( state ) {
                 case self.CONST.STATE_DISPLAY.VISIBLE:
                     SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( 0, _dom, type_element );
@@ -137,10 +152,19 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
                     SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( 0, _dom, type_element );
                     break;
                 case self.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED:
+                    SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( 0, _dom, type_element );
+                    SHINKEN.TOOLS.TEST_AUTO.__hasStyle( _dom, "opacity", "0.3" );
+                    break;
+                case self.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED_AND_NO_EVENT:
                     SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( 0, _dom, type_element );
                     SHINKEN.TOOLS.TEST_AUTO.__hasStyle( _dom, "pointerEvents", 'none' );
                     SHINKEN.TOOLS.TEST_AUTO.__hasStyle( _dom, "opacity", "0.3" );
                     break;
+                case self.CONST.STATE_DISPLAY.VISIBLE_AND_CHILDREN_DISABLED:
+                    SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( 0, _dom, type_element );
+                    SHINKEN.TOOLS.TEST_AUTO.__hasStyle( _dom.firstElementChild, "pointerEvents", 'none' );
+                    SHINKEN.TOOLS.TEST_AUTO.__hasStyle( _dom, "opacity", "0.3" );
+                    break;
                 default:
                     break;
             }
@@ -148,6 +172,9 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
         }, timeout );
         return _to_return;
     };
+    self.TEST.IFRAME.displayState     = function ( timeout, type_element, state ) {
+        return self.TEST.displayState( timeout, type_element, state, true );
+    };
     self.TEST.WIDGET.count            = function ( timeout, total_number_element_expected, number_with_errors, number_with_warning ) {
         var _to_return = 500;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'TEST.WIDGET.count', total_number_element_expected + "-" + number_with_errors + "-" + number_with_warning );
@@ -169,7 +196,6 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
             var _dom_element = self.DOM.getWidgetArea( widget_type, widget_index, widget_area );
-            
             switch ( state ) {
                 case self.CONST.STATE_DISPLAY.HIDDEN:
                     SHINKEN.TOOLS.TEST_AUTO_DOM.hasNoWidth( 0, _dom_element, widget_area );
@@ -274,7 +300,7 @@ SHINKEN.TOOLS.TEST_AUTO_WEATHER = (function ( self ) {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
             var _timeout = SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( 0, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_new_service_weather" );
             _timeout += SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' );
-            _timeout += SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout, name, user_name );
+            _timeout += SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.createJSONInForm( _timeout, name, user_name );
             _timeout += SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' );
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
         }, timeout );
