@@ -163,11 +163,11 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         return _check.querySelector( '.shinken-tab-check-col-name .shinken-label .shinken-link' );
     };
     //********************************************  ACTION   **************************************************//
-    self.ACTION.navigateInTabOverride                   = function ( timeout, tab_name, id_host, id_check, dfe ) {
+    self.ACTION.navigateInTabOverride            = function ( timeout, tab_name, id_host, id_check, dfe ) {
         _value = tab_name + "-override-" + self._buildCheckID( id_host, id_check, dfe );
         return SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( timeout, _value );
     };
-    self.ACTION.cleanAllOverridesByButton               = function ( timeout, id_host, id_check, dfe ) {
+    self.ACTION.cleanAllOverridesByButton        = function ( timeout, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _dom = self.getCleanAllButton( id_host, id_check, dfe );
             //SHINKEN.TOOLS.TEST_AUTO_DOM.click(0, _dom);
@@ -190,7 +190,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return 4000;
     };
-    self.ACTION.closeTryCheckPanel                      = function ( timeout, id_host, id_check, dfe ) {
+    self.ACTION.closeTryCheckPanel               = function ( timeout, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _button = self.getTryCheckButtonClose( id_host, id_check, dfe );
             SHINKEN.TOOLS.TEST_AUTO.__isVisible( _button, 'button close try check ' + self._buildCheckID( id_host, id_check, dfe ) );
@@ -199,7 +199,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return 1000;
     };
-    self.ACTION.goToMode                                = function ( tab_id, timeout ) {
+    self.ACTION.goToMode                         = function ( tab_id, timeout ) {
         setTimeout( function () {
             document.querySelector( ".shinken-check-mode-menu-tab[data-value='" + tab_id + "']" ).click();
         }, timeout );
@@ -228,7 +228,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.ACTION.clickOnButtonExclude                    = function ( timeout, id_host, id_check, dfe ) {
+    self.ACTION.clickOnButtonExclude             = function ( timeout, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _mode_check     = self.getModeCheck();
             var _status_exclude = self.getCheckExcludeStatus( id_host, id_check, dfe );
@@ -258,7 +258,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return 2000;
     };
-    self.ACTION.clickOnButtonRemoveExclude              = function ( timeout, id_host, id_check, dfe ) {
+    self.ACTION.clickOnButtonRemoveExclude       = function ( timeout, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _mode_check = self.getModeCheck();
             switch ( _mode_check ) {
@@ -313,7 +313,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return 10;
     };
-    self.TEST.counterCheck                        = function ( timeout, nb_error, nb_warning, id_host, id_check, dfe ) {
+    self.TEST.counterCheck                       = function ( timeout, nb_error, nb_warning, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _counters = self.getCheckInPageHostCountersDomElement( id_host, id_check, dfe );
             SHINKEN.TOOLS.TEST_AUTO_COMPONENT.TEST.hasCounterValue( 0, _counters[ 0 ], nb_error );
@@ -413,7 +413,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return 50;
     };
-    self.TEST.hasExcludeButtonStatus                  = function ( timeout, status, id_host, id_check, dfe ) {
+    self.TEST.hasExcludeButtonStatus             = function ( timeout, status, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _button_by_id          = self.getButtonExcludeByID( id_host, id_check, dfe );
             var _button_by_name        = self.getButtonExcludeByName( id_host, id_check, dfe );
@@ -586,7 +586,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         return 200;
     };
     self.TEST.statusTryCheckAfterRunModulate     = function ( timeout, status_expected, id_host, id_check, dfe ) {
-        if ( __version_shinken === "V02.07.06" ){
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA ){
             return 0;
         }
         setTimeout( function () {
@@ -596,7 +596,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         return 200;
     };
     self.TEST.resultTryCheckAfterRun             = function ( timeout, id_host, id_check, dfe, name_host, name_check ) {
-        if ( __version_shinken === "V02.07.06" ){
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA ){
             return 0;
         }
         var _text_expected = "";
@@ -608,7 +608,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
                 break;
             case "00122-4":
             case "00122-6":
-                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST._00122.RESULT;
+                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL._00122.RESULT;
                 break;
             case "00212-1":
                 _text_expected = "Name or service not known";
@@ -625,7 +625,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         return 100;
     };
     self.TEST.commandLineTryCheckAfterRun        = function ( timeout, id_host, id_check, dfe, name_host, name_check ) {
-        if ( __version_shinken === "V02.07.06" ){
+        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA ){
             return 0;
         }
         var _text_expected = "";
@@ -634,10 +634,10 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         switch ( _switch_value ) {
             case "00122-4":
             case "00122-6":
-                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST._00122.COMMAND_LINE;
+                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL._00122.COMMAND_LINE;
                 break;
             case "00122-8":
-                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST._00122.COMMAND_LINE_7;
+                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL._00122.COMMAND_LINE_7;
                 break;
             default:
                 _text_expected = "echo [$ARG1$] [$ARG2$]";
@@ -656,10 +656,10 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         
         switch ( _switch_value ) {
             case "00122-4":
-                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST._00122.COMMAND_LINE_INTERPRETED.PHASE_4;
+                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL._00122.COMMAND_LINE_INTERPRETED.PHASE_4;
                 break;
             case "00122-6":
-                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST._00122.COMMAND_LINE_INTERPRETED.PHASE_6;
+                _text_expected = SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL._00122.COMMAND_LINE_INTERPRETED.PHASE_6;
                 break;
             case "00178-1":
                 _text_expected = "echo ['aaaa'] []";
@@ -774,7 +774,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         return 10;
     };
     //********************************************  TEST TAGS  **************************************************//
-    self.TEST.hasHiddenTagState      = function ( timeout, state_expected, id_host, id_check, dfe ) {
+    self.TEST.hasHiddenTagState                  = function ( timeout, state_expected, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _tag = self.getHiddenTag( id_host, id_check, dfe );
             switch ( state_expected ) {
@@ -788,7 +788,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return 100;
     };
-    self.TEST.hasDuplicateTagState        = function ( timeout, state_expected, id_host, id_check, dfe ) {
+    self.TEST.hasDuplicateTagState               = function ( timeout, state_expected, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _tag = self.getDuplicatedTag( id_host, id_check, dfe );
             switch ( state_expected ) {
@@ -803,7 +803,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         }, timeout );
         return 100;
     };
-    self.TEST.tagModulation          = function ( timeout, state, id_host, id_check, dfe ) {
+    self.TEST.tagModulation                      = function ( timeout, state, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _dom_tag_info = self._getTagModulation( id_host, id_check, dfe );
             switch ( state ) {
@@ -818,7 +818,7 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         return 10;
     };
     //********************************************  TEST OVERRIDE  **************************************************//
-    self.TEST.hasOverrideUI          = function ( timeout, id_host, id_check, dfe ) {
+    self.TEST.hasOverrideUI                      = function ( timeout, id_host, id_check, dfe ) {
         var _to_return = 100;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'hasOverrideUI', self._buildCheckID( id_host, id_check, dfe ) );
         setTimeout( function () {
@@ -830,21 +830,21 @@ SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB = (function ( self ) {
         return _to_return;
     };
     //********************************************  TEST MISC  **************************************************//
-    self.TEST.cfgOverrideText        = function ( timeout, text_expected ) {
+    self.TEST.cfgOverrideText                    = function ( timeout, text_expected ) {
         setTimeout( function () {
             var _text = self.getCfgOverrideText();
             SHINKEN.TOOLS.TEST_AUTO.__isInnerTextEqualTo( _text, text_expected, 'Syntaxe des surcharges de check' );
         }, timeout );
         return 2000;
     };
-    self.TEST.isTextCommand          = function ( timeout, value, id_host, id_check, dfe ) {
+    self.TEST.isTextCommand                      = function ( timeout, value, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _command = self.getCommand( id_host, id_check, dfe );
             SHINKEN.TOOLS.TEST_AUTO.__isInnerTextEqualTo( _command, value );
         }, timeout );
         return 100;
     };
-    self.TEST.commandErrorAndWarning = function ( timeout, nb_error, nb_warning, id_host, id_check, dfe ) {
+    self.TEST.commandErrorAndWarning             = function ( timeout, nb_error, nb_warning, id_host, id_check, dfe ) {
         setTimeout( function () {
             var _errors = self.getMacrosInCommand( "shinken-macro-error", id_host, id_check, dfe );
             SHINKEN.TOOLS.TEST_AUTO.___isArrayLengthEqualsTo( _errors, nb_error, "nb errors in macro" );
