@@ -25,9 +25,23 @@ SHINKEN.TOOLS.TEST_AUTO       = (function ( self ) {
         }
         _messages[ __shinken_test_type ].push( new OBJECT.Message( COMPONENT.CONST.STATUS.WARNING, "[" + __shinken_test_type + "] - " + text_message ) );
     };
-    self.buildMessage             = function ( timeout ) {
-        SHINKEN.TOOLS.TEST_AUTO_LOGGER.showInConsole();
+    self.addInfo                  = function ( text_message ) {
+        if ( !_messages[ __shinken_test_type ] ) {
+            _messages[ __shinken_test_type ] = [];
+        }
+        _messages[ __shinken_test_type ].push( new OBJECT.Message( COMPONENT.CONST.STATUS.INFO, "[" + __shinken_test_type + "] - " + text_message ) );
+    };
+    self.MakeFinalAction             = function ( timeout ) {
         setTimeout( function () {
+            self.buildMessage(0);
+            if ( !__is_single ) {
+                SHINKEN.TOOLS.TEST_AUTO_PHASE.doNext();
+            }
+        }, timeout );
+    };
+    self.buildMessage             = function ( timeout ) {
+        setTimeout( function () {
+            SHINKEN.TOOLS.TEST_AUTO_LOGGER.showInConsole();
             if ( _has_script_error ) {
                 self.addError( _has_script_error + ' error(s) javascript detected' );
             }
@@ -49,10 +63,29 @@ SHINKEN.TOOLS.TEST_AUTO       = (function ( self ) {
                     var _dom_to_add = DOM.Service.createElement( "div", { style: "background: red;z-index:999999;position: absolute;top:10px" }, _to_write.buildMessage() );
                     DOM.Service.addElementTo( _dom_to_add, DOM.BodyService.getDomElement() );
                 }
+                
+                switch ( _to_write.getStatus() ) {
+                    case COMPONENT.CONST.STATUS.ERROR:
+                        SHINKEN.TOOLS.TEST_AUTO_LOGGER.ACTION.logToServer( __shinken_test_type, __phase, SHINKEN.TOOLS.TEST_AUTO.CONST.STATUS.ERROR, _to_write.buildMessage() );
+                        break;
+                    case COMPONENT.CONST.STATUS.WARNING:
+                        SHINKEN.TOOLS.TEST_AUTO_LOGGER.ACTION.logToServer( __shinken_test_type, __phase, SHINKEN.TOOLS.TEST_AUTO.CONST.STATUS.WARNING, _to_write.buildMessage() );
+                        break;
+                    case COMPONENT.CONST.STATUS.BEWARE:
+                        SHINKEN.TOOLS.TEST_AUTO_LOGGER.ACTION.logToServer( __shinken_test_type, __phase, SHINKEN.TOOLS.TEST_AUTO.CONST.STATUS.BEWARE, _to_write.buildMessage() );
+                        break;
+                    default:
+                        SHINKEN.TOOLS.TEST_AUTO_LOGGER.ACTION.logToServer( __shinken_test_type, __phase, SHINKEN.TOOLS.TEST_AUTO.CONST.STATUS.INFO, _to_write.buildMessage() );
+                        break;
+                }
+                
             }
             else if ( !__is_single ) {
-                SHINKEN.TOOLS.TEST_AUTO_PHASE.doNext();
-                console.log( "[TEST_AUTO DONE]", __shinken_test_type, "[OK]", "__do_next = " + __do_next, "phase" + __phase );
+                SHINKEN.TOOLS.TEST_AUTO_LOGGER.ACTION.logToServer( __shinken_test_type, __phase, SHINKEN.TOOLS.TEST_AUTO.CONST.STATUS.VALID, "" );
+                console.log( "[TEST_AUTO DONE]", __shinken_test_type, SHINKEN.TOOLS.TEST_AUTO.CONST.STATUS.VALID, "__do_next = " + __do_next, "phase" + __phase );
+            }
+            else {
+                console.log( "[TEST_AUTO DONE]" );
             }
         }, timeout );
         
@@ -61,13 +94,13 @@ SHINKEN.TOOLS.TEST_AUTO       = (function ( self ) {
     self.TEST.isConfigEveryone    = function ( timeout, inverted ) {
         setTimeout( function () {
             if ( PROPERTY.UserRightsBehaviour.has_everybody_default && inverted ) {
-                SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeViewContactDefaultValue("nobody");
+                SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeViewContactDefaultValue( "nobody" );
             }
             else if ( !PROPERTY.UserRightsBehaviour.has_everybody_default && !inverted ) {
-                SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeViewContactDefaultValue("everyone");
+                SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeViewContactDefaultValue( "everyone" );
             }
         }, timeout );
-        return 2500;
+        return 10000;
     };
     self.___isVariableEqualsTo    = function ( object, key, value_expected, extra_label ) {
         if ( !extra_label ) {
@@ -205,7 +238,18 @@ SHINKEN.TOOLS.TEST_AUTO       = (function ( self ) {
         if ( _value !== value_expected ) {
             SHINKEN.TOOLS.TEST_AUTO.addError( extra_label + "Le style <b>" + key + "</b> de <b>" + text_desc + "</b> n'est pas égale à <b>" + value_expected + "</b> ==> <b>[" + _value + "]</b>" );
         }
-        
+    };
+    self.__hasNotStyle              = function ( dom_element, key, value_expected, text_desc, extra_label ) {
+        if ( !extra_label ) {
+            extra_label = "";
+        }
+        if ( !text_desc && dom_element ) {
+            text_desc = dom_element.innerText;
+        }
+        var _value = DOM.Service.getComputedStyle( dom_element, key );
+        if ( _value === value_expected ) {
+            SHINKEN.TOOLS.TEST_AUTO.addError( extra_label + "Le style <b>" + key + "</b> de <b>" + text_desc + "</b> est égale à <b>" + value_expected + "</b> ==> <b>[" + _value + "]</b>" );
+        }
     };
     self.__hasClass                 = function ( dom_element, class_name, text_desc, extra_label, inverse ) {
         if ( !extra_label ) {
@@ -259,6 +303,24 @@ SHINKEN.TOOLS.TEST_AUTO       = (function ( self ) {
         }
         
     };
+    self.__click                    = function ( dom_element, force_click, deepness ) {
+        if ( !dom_element ) {
+            SHINKEN.TOOLS.TEST_AUTO.addError( "click on impossible ==>  dom_element 'undefined'" );
+        }
+        else {
+            var _compute = DOM.Service.getComputedStyle( dom_element );
+            if ( !force_click && _compute.pointerEvents === 'none' ) {
+                SHINKEN.TOOLS.TEST_AUTO.addError( "click on  <b>" + dom_element.innerText + "</b> impossible pointerEvents === 'none'" );
+            }
+            else if ( !force_click && !DOM.Service.isVisible( dom_element, deepness ) ) {
+                SHINKEN.TOOLS.TEST_AUTO.addError( "click on  <b>" + dom_element.innerText + "</b> impossible non visible" );
+            }
+            else {
+                dom_element.click();
+                dom_element.focus();
+            }
+        }
+    };
     self.__doesntExist              = function ( dom_element, text_desc, extra_label ) {
         if ( !dom_element ) {
             return;
@@ -363,18 +425,21 @@ SHINKEN.TOOLS.TEST_AUTO_PHASE = (function ( self ) {
     self.ACTION             = {};
     //********************************************  NEXT    ******************************************************//
     self.doNext             = function ( timeout, forced_shinken_test_type, forced_phase ) {
+        timeout               = timeout || 0;
         window.onbeforeunload = function () {
         };
-        if ( !SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ __shinken_test_type ] ) {
+        if ( !SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ] ) {
             return;
         }
-        if ( SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ __shinken_test_type ].cancel_next ) {
+        if ( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].cancel_next ) {
             return;
         }
-        var _timeout   = timeout + 2000;
-        var _max_phase = SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ __shinken_test_type ].phases || 1;
-        if ( Array.isArray( SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ __shinken_test_type ].address ) ) {
-            _max_phase = SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ __shinken_test_type ].address.length;
+        
+        
+        var _timeout   = timeout + 4000;
+        var _max_phase = SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].phases || 1;
+        if ( Array.isArray( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].address ) ) {
+            _max_phase = SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ __shinken_test_type ].address.length;
         }
         var _has_other_phase = __phase < _max_phase;
         var _next;
@@ -385,12 +450,20 @@ SHINKEN.TOOLS.TEST_AUTO_PHASE = (function ( self ) {
         else {
             __phase = 1;
             _next   = SHINKEN.TOOLS.STRING.prefix_by_zero( parseInt( __shinken_test_type ) + 1, 5 );
+            if ( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ _next ] && SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ _next ].version_minimum ) {
+                if ( __version_shinken < SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ _next ].version_minimum ) {
+                    __shinken_test_type = _next;
+                    __phase             = 9999;
+                    return self.doNext( timeout );
+                }
+            }
+            
         }
-        if ( !SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ _next ] || !SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ _next ].address ) {
+        if ( !SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ _next ] || !SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ _next ].address ) {
             console.log( "GREG", "[FIN DES TEST AUTO]", "[1]" );
             return;
         }
-        if ( Array.isArray( SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ _next ].address ) && !SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ _next ].address[ __phase - 1 ] ) {
+        if ( Array.isArray( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ _next ].address ) && !SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ _next ].address[ __phase - 1 ] ) {
             console.log( "GREG", "[FIN DES TEST AUTO]", "[2]" );
             return;
         }
@@ -402,7 +475,6 @@ SHINKEN.TOOLS.TEST_AUTO_PHASE = (function ( self ) {
         if ( forced_shinken_test_type && forced_phase ) {
             SHINKEN.HIGHWAY.goTo( self.getNextLink( forced_shinken_test_type, forced_phase ) );
         }
-        
     };
     self.doNextWhen         = function ( timeout, function_to_eval ) {
         __do_next = false;
@@ -410,7 +482,7 @@ SHINKEN.TOOLS.TEST_AUTO_PHASE = (function ( self ) {
             var _test = eval( function_to_eval );
             if ( _test ) {
                 __do_next = true;
-                self.doNext( 0, __shinken_test_type, __phase ); //TEST 00142
+                self.doNext( 0, __shinken_test_type, parseInt( __phase + 1 ) ); //TEST 00142
             }
             else {
                 self.doNextWhen( 1000, function_to_eval );
@@ -430,31 +502,32 @@ SHINKEN.TOOLS.TEST_AUTO_PHASE = (function ( self ) {
         return 50;
     };
     self.getNextLink        = function ( next, phase, add_existing_argument ) {
-        console.log( "GSOU", "[TEST_AUTO_PHASE - getNextLink]", next, phase );
-        var _params      = SHINKEN.HIGHWAY.getParams();
-        var _new_address = Array.isArray( SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ next ].address ) ? SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ next ].address[ phase - 1 ] : SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ next ].address;
-        var _to_return   = _new_address + "?shinken_test_auto=" + next + "&phase=" + phase;
+        var _params                          = SHINKEN.HIGHWAY.getParams();
+        var _new_address                     = Array.isArray( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ next ].address ) ? SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ next ].address[ phase - 1 ] : SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ next ].address;
+        var _new_address_split_with_hashtag  = _new_address.split( '#' );
+        _new_address_split_with_hashtag[ 0 ] = _new_address_split_with_hashtag[ 0 ] + "?shinken_test_auto=" + next + "&phase=" + phase;
+        var _to_return                       = _new_address_split_with_hashtag.join( "#" );
         if ( SHINKEN.TOOLS.STRING.contains( _new_address, "?" ) ) {
             _to_return = _new_address + "&shinken_test_auto=" + next + "&phase=" + phase;
         }
-        if ( add_existing_argument ){
+        if ( add_existing_argument ) {
             var _keys = Object.keys( _params );
             var _current_key;
-            for( var i = 0, _size = _keys.length ; i < _size; i++ ) {
-                _current_key = _keys[i];
+            for ( var i = 0, _size = _keys.length; i < _size; i++ ) {
+                _current_key = _keys[ i ];
                 switch ( _current_key ) {
                     case "shinken_test_auto":
                     case "phase":
                         break;
                     default:
-                        _to_return += "&" + _current_key + "=" + _params[_current_key];
+                        _to_return += "&" + _current_key + "=" + _params[ _current_key ];
                         break;
                 }
             }
         }
         var _port;
-        if ( SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ next ][ "port" ] && __version_shinken > "V02.08.01" ) {
-            _port = Array.isArray( SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ next ].port ) ? SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ next ].port[ phase - 1 ] : SHINKEN.TOOLS.TEST_AUTO.CONST.STRUCTURE[ next ].port;
+        if ( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ next ][ "port" ] ) {
+            _port = Array.isArray( SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ next ].port ) ? SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ next ].port[ phase - 1 ] : SHINKEN.TOOLS.TEST_AUTO.STRUCTURE[ next ].port;
         }
         else {
             _port = 7766;
@@ -493,10 +566,10 @@ SHINKEN.TOOLS.TEST_AUTO_TOOLTIP = (function ( self ) {
 })( SHINKEN.TOOLS.TEST_AUTO_TOOLTIP || {} );
 
 SHINKEN.TOOLS.TEST_AUTO_DOM = (function ( self ) {
-    self.TEST                     = {};
-    self.ACTION                   = {};
+    self.TEST                = {};
+    self.ACTION              = {};
     //********************************************  EVENT   **********************************************************//
-    self.dispatchEvent            = function ( timeout, dom_element, event_to_dispatch, times ) {
+    self.dispatchEvent       = function ( timeout, dom_element, event_to_dispatch, times ) {
         setTimeout( function () {
             if ( !times ) {
                 times = 1;
@@ -507,7 +580,7 @@ SHINKEN.TOOLS.TEST_AUTO_DOM = (function ( self ) {
         }, timeout );
         return 300;
     };
-    self.click                    = function ( timeout, dom_element, force_click, deepness ) {
+    self.click               = function ( timeout, dom_element, force_click, deepness ) {
         setTimeout( function () {
             if ( !dom_element ) {
                 SHINKEN.TOOLS.TEST_AUTO.addError( "click on impossible ==>  dom_element 'undefined'" );
@@ -528,6 +601,14 @@ SHINKEN.TOOLS.TEST_AUTO_DOM = (function ( self ) {
         }, timeout );
         return 500;
     };
+    self.clickOnFuturElement = function ( timeout, css_selector, force_click, deepness ) {
+        setTimeout( function () {
+            SHINKEN.TOOLS.TEST_AUTO.__click( document.querySelector( css_selector ), deepness );
+            
+        }, timeout );
+        return 1000;
+    };
+    
     self.shiftClick               = function ( timeout, dom_element ) {
         setTimeout( function () {
             if ( !dom_element ) {
@@ -642,6 +723,12 @@ SHINKEN.TOOLS.TEST_AUTO_DOM = (function ( self ) {
             return self.isNotVisible( timeout, dom_element, text_desc );
         }
     };
+    self.isVisibleWithDomInFuture = function ( timeout, css_selector, text_desc ) {
+        setTimeout( function () {
+            SHINKEN.TOOLS.TEST_AUTO.__isVisible( document.querySelector( css_selector ), text_desc );
+        }, timeout );
+        return 1500;
+    };
     self.isVisible                = function ( timeout, dom_element, text_desc ) {
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO.__isVisible( dom_element, text_desc );
@@ -707,6 +794,12 @@ SHINKEN.TOOLS.TEST_AUTO_DOM = (function ( self ) {
         }, timeout );
         return 10;
     };
+    self.hasNotStyle              = function ( timeout, dom_element, key, value_expected, description ) {
+        setTimeout( function () {
+            SHINKEN.TOOLS.TEST_AUTO.__hasNotStyle( dom_element, key, value_expected, description );
+        }, timeout );
+        return 10;
+    };
     self.hasData                  = function ( timeout, dom_element, key, value_expected, description ) {
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO.___isVariableEqualsTo( dom_element.dataset, key, value_expected, description );
@@ -881,19 +974,19 @@ SHINKEN.TOOLS.TEST_AUTO_XSS = (function ( self ) {
 })( SHINKEN.TOOLS.TEST_AUTO_XSS || {} );
 
 SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW = (function ( self ) {
-    self.DOM                  = {};
-    self.TEST                 = {};
-    self.ACTION               = {};
-    self.instance         = null;
+    self.DOM           = {};
+    self.TEST          = {};
+    self.ACTION        = {};
+    self.instance      = null;
     //********************************************  TEST   **************************************************//
-    self.TEST.pathName            = function ( timeout, path_name ) {
+    self.TEST.pathName = function ( timeout, path_name ) {
         setTimeout( function () {
-            SHINKEN.TOOLS.TEST_AUTO.__isTextEqualTo(path_name, self.instance.location.pathname, "URL WINDOW" )
+            SHINKEN.TOOLS.TEST_AUTO.__isTextEqualTo( path_name, self.instance.location.pathname, "URL WINDOW" );
         }, timeout );
         return 200;
     };
     //********************************************  ACTION   **************************************************//
-    self.ACTION.close            = function ( timeout ) {
+    self.ACTION.close  = function ( timeout ) {
         setTimeout( function () {
             if ( self.instance ) {
                 self.instance.close();
@@ -901,7 +994,7 @@ SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW = (function ( self ) {
         }, timeout );
         return 200;
     };
-    self.ACTION.open             = function ( timeout, url ) {
+    self.ACTION.open   = function ( timeout, url ) {
         setTimeout( function () {
             self.instance = window.open( url, "test", "width=" + window.innerWidth / 1.2 + ",height=" + window.innerHeight / 1.2 );
         }, timeout );
