@@ -11,11 +11,12 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
     
     self.do = function () {
         switch ( __shinken_test_type ) {
-            case "00195":
+            case"00195":
                 switch ( __phase ) {
                     case 1:
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.visibility( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "barre du menu", true ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.userNameLabel( _timeout, 'test_auto_user_executor' ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.logout( _timeout ) );
                         break;
                     case 2:
@@ -27,7 +28,7 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         break;
                     case 3:
                         ____( SHINKEN.TOOLS.TEST_AUTO_DOM.visibility( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "barre du menu", true ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "height", 60, "barre du menu" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.hasStyle( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getMenu(), "height", 63, "barre du menu" ) );
                         break;
                     case 4:
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnMenu( _timeout, SHINKEN.SCREEN.TYPE.HIVE ) );
@@ -265,10 +266,9 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 7, 1 ) );
                         break;
                     case 3: //TEST STRUCTURE AND INTERACTIONS
-                        
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.headersNumber( _timeout, 8 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.filtersNumber( _timeout, 8 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.headersNumber( _timeout, 9 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.filtersNumber( _timeout, 9 ) );
                         break;
                     case 4: //TRI + SHIFT CLICK
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
@@ -359,8 +359,8 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                     case 8: //CHANGE NAME + FILTER & SORTING
                         //__do_next = false;
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_light" ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.headersNumber( _timeout, 2 ) );
-                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.filtersNumber( _timeout, 2 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.headersNumber( _timeout, 3 ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.filtersNumber( _timeout, 3 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "current_owner", "test_auto_user_executor" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.viewsNumber( _timeout, 4, 2 ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.filter( _timeout, "current_owner", "" ) );
@@ -369,7 +369,6 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.ACTION.clickOnHeaderLabel( _timeout, "current_owner" ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.displayAtLine( _timeout, "test_auto_3", 1 ) );
                         
-                        
                         break;
                 }
                 break;
@@ -377,7 +376,6 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                 switch ( __phase ) {
                     case 1:
                         ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" ) );
-                        
                         break;
                     case 2: //NUMBER ERROR WEATHER PREVIEW
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
@@ -396,8 +394,6 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                         ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.TEST.counter( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "" ) );
                         break;
-                    
-                    
                 }
                 break;
             case "00222":
@@ -408,6 +404,128 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN = (function ( self ) {
                 ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.LIST, "menu_expand_list_all" ) );
                 ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR.TEST.displayHelp( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_ANGULAR_CONST.STATE.HIDDEN ) );
                 break;
+            case "00233":
+                var user_properties_configuration_path    = "/etc/shinken-user/configuration/elements_default_properties/default_properties_configuration.cfg";
+                var default_properties_configuration_path = "/etc/shinken/_default/elements_default_properties/default_properties_configuration.cfg";
+                
+                switch ( __phase ) {
+                    case 1:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, user_properties_configuration_path ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, default_properties_configuration_path ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "synchronizer", false ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "arbiter", false ) );
+                        break;
+                    case 2:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 3:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 4:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 5:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 6:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 7:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 8:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 9:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 10:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.helpLabelPropertyAndPropertyLabel( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 11:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.NOTE_URL, "http://00233_test_auto_host_diff" ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
+                        __do_next = false;
+                        break;
+                    case 13:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelPropertyDiffPopup( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 14:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.TEST.labelProperty( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 15:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( _timeout, WINDOW.CONST.ELEMENT.CHANGES ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.labelPropertyDiff( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 16:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonDifference( _timeout ) );
+                        __do_next = false;
+                        break;
+                    case 17:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonSubmitToStagging( _timeout ) );
+                        __do_next = false;
+                        break;
+                    case 19:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelPropertyProposedPopup( _timeout, "00000000000000000000000000000233", PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 20:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_PAGE_EDIT.TEST.labelPropertyPropose( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        break;
+                    case 21:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.saveWithButtonAcceptPropose( _timeout ) );
+                        break;
+                }
+                break;
+            case "00235":
+                var _user_properties_configuration_path    = "/etc/shinken-user/configuration/elements_default_properties/default_properties_configuration.cfg";
+                var _default_properties_configuration_path = "/etc/shinken/_default/elements_default_properties/default_properties_configuration.cfg";
+                
+                switch ( __phase ) {
+                    case 1:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, _user_properties_configuration_path ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.removeFileIfExists( _timeout, _default_properties_configuration_path ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "synchronizer", false ) );
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.restart( _timeout, "arbiter", false ) );
+                        break;
+                    case 2:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.ACTION.addExtraColumn( _timeout, PROPERTY.CONST.NAME.NOTE_URL ) );
+                        break;
+                    case 3:
+                        ____( SHINKEN.TOOLS.TEST_AUTO_LIST_ALL.TEST.labelColumnHeader( _timeout, PROPERTY.CONST.NAME.NOTE_URL, lang_fr.hosts.notes_url ) );
+                        __do_next = false;
+                        break;
+                }
+                break;
+            case "00236":
+                
+                switch ( __phase ) {
+                    case 1:
+                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_00236_favorite_all_right", "test_auto_00236_favorite_all_right" ) );
+                        break;
+                    case 2:
+                        _timeout += 1000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
+                        break;
+                    case 3:
+                        _timeout += 1000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
+                        break;
+                    case 4:
+                        ____( SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_00236_no_favorite_create_right", "test_auto_00236_no_favorite_create_right" ) );
+                        break;
+                    case 5:
+                        _timeout += 1000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
+                        break;
+                    case 6:
+                        _timeout += 1000;
+                        ____( SHINKEN.TOOLS.TEST_AUTO_DOM.isNotVisible( _timeout, SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.DOM.getAddToFavoriteButton() ) );
+                        __do_next = false;
+                        break;
+                }
+                break;
             default:
                 ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_LIST_ALL_RUN.do( _timeout ) );
                 break;
