@@ -1,66 +1,66 @@
 SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER = (function ( self ) {
-    self.DOM                          = {};
-    self.DOM.CHANGE                   = {};
-    self.TEST                         = {};
-    self.ACTION                       = {};
-    self.CONST                        = {};
-    var _INTERNAL                     = {};
+    self.DOM                           = {};
+    self.DOM.CHANGE                    = {};
+    self.TEST                          = {};
+    self.ACTION                        = {};
+    self.CONST                         = {};
+    var _INTERNAL                      = {};
     //********************************************  GET DOM ELEMENT   **************************************************//
-    self.DOM.getIframe                = function () {
+    self.DOM.getIframe                 = function () {
         return SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.DOM.getIframe();
     };
-    self.DOM.tabsNavigation           = function () {
+    self.DOM.tabsNavigation            = function () {
         return self.DOM.getIframe().querySelector( "#id-shinken-container-panels-view .shinken-view-manager-navigation" );
     };
-    self.DOM.tabNavigation            = function () {
+    self.DOM.tabNavigation             = function () {
         return self.DOM.tabsNavigation().querySelector( '.shinken-window-element[data-name="weather_service"]' );
     };
-    self.DOM.tabNavigationTotal       = function () {
+    self.DOM.tabNavigationTotal        = function () {
         return self.DOM.tabNavigation().querySelector( ".shinken-counter.shinken-total-counter" );
     };
-    self.DOM.getAllLineData           = function () {
+    self.DOM.getAllLineData            = function () {
         return self.DOM.getIframe().querySelectorAll( ".shinken-list-line" );
     };
-    self.DOM.getButtonRemove          = function ( line_dom ) {
-        return line_dom.querySelector( ".shinicon-delete" );
+    self.DOM.getButtonRemove           = function ( line_dom ) {
+        return line_dom.querySelector( ".shinken-bin-icon" );
     };
-    self.DOM.getClosePopup            = function () {
+    self.DOM.getClosePopup             = function () {
         return self.DOM.getIframe().querySelector( "#id-shinken-confirmation-popup-container" );
     };
-    self.DOM.getClosePopupButtonOK    = function () {
+    self.DOM.getClosePopupButtonOK     = function () {
         return self.DOM.getClosePopup().querySelector( ".shinken-action-button-confirmation-popup.shinken-validate-button" );
     };
-    self.DOM.getClosePopupButtonNOK   = function () {
+    self.DOM.getClosePopupButtonNOK    = function () {
         return self.DOM.getClosePopup().querySelector( ".shinken-action-button-confirmation-popup.shinken-cancel-button" );
     };
-    self.DOM.headers                  = function () {
+    self.DOM.headers                   = function () {
         return self.DOM.getIframe().querySelectorAll( ".shinken-list-container-fix-header-filter .shinken-list-header" );
     };
-    self.DOM.header                   = function ( header_name ) {
+    self.DOM.header                    = function ( header_name ) {
         return self.DOM.getIframe().querySelector( '.shinken-list-container-fix-header-filter .shinken-list-header[data-name="' + header_name + '"]' );
     };
-    self.DOM.headerLabel              = function ( header_name ) {
+    self.DOM.headerLabel               = function ( header_name ) {
         return self.DOM.header( header_name ).querySelector( ".shinken-list-header-name" );
     };
-    self.DOM.headerButton             = function ( header_name ) {
+    self.DOM.headerButton              = function ( header_name ) {
         return self.DOM.header( header_name ).querySelector( ".shinken-sort-popup-button" );
     };
-    self.DOM.headerButtonMenuOption   = function ( header_name, data_name ) {
+    self.DOM.headerButtonMenuOption    = function ( header_name, data_name ) {
         return self.DOM.header( header_name ).querySelector( '.shinken-list-header-sort-popup-option[data-name="' + data_name + '"]' );
     };
-    self.DOM.headerSortingIndex       = function ( header_name ) {
+    self.DOM.headerSortingIndex        = function ( header_name ) {
         return self.DOM.header( header_name ).querySelector( ".shinken-list-header-sort-priority-number" );
     };
-    self.DOM.headerSortingIcon        = function ( header_name ) {
+    self.DOM.headerSortingIcon         = function ( header_name ) {
         return self.DOM.header( header_name ).querySelector( ".shinken-list-header-sort-priority-icon-cell" );
     };
-    self.DOM.filters                  = function () {
+    self.DOM.filters                   = function () {
         return self.DOM.getIframe().querySelectorAll( ".shinken-list-container-fix-header-filter .shinken-list-filter" );
     };
-    self.DOM.lines                    = function () {
+    self.DOM.lines                     = function () {
         return self.DOM.getIframe().querySelectorAll( ".shinken-list-container-with-scroll .shinken-list-line" );
     };
-    self.DOM.lineWithName             = function ( line_name ) {
+    self.DOM.lineWithName              = function ( line_name ) {
         var _doms = self.DOM.lines();
         for ( var i = 0, _size_i = _doms.length; i < _size_i; i++ ) {
             if ( _INTERNAL.isLine( _doms[ i ], line_name ) ) {
@@ -69,29 +69,29 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER = (function ( self ) {
         }
         return null;
     };
-    self.DOM.linesNotFiltered         = function () {
+    self.DOM.linesNotFiltered          = function () {
         return self.DOM.getIframe().querySelectorAll( ".shinken-list-container-with-scroll .shinken-list-line:not(.shinken-is-filtered)" );
     };
-    self.DOM.CHANGE.buttonOpen        = function ( dom_element_line ) {
+    self.DOM.CHANGE.buttonOpen         = function ( dom_element_line ) {
         return dom_element_line.querySelector( ".shinken-button-change-view-owner" );
     };
-    self.DOM.CHANGE.input             = function ( dom_element_line ) {
+    self.DOM.CHANGE.input              = function ( dom_element_line ) {
         return dom_element_line.querySelector( ".shinken-input" );
     };
-    self.DOM.CHANGE.buttonValidChange = function ( dom_element_line ) {
+    self.DOM.CHANGE.buttonValidChange  = function ( dom_element_line ) {
         return dom_element_line.querySelector( ".shinken-change-owner-popup-button.shinken-change-owner-apply-button" );
     };
-    self.DOM.cell                     = function ( dom_element_line, cell_name ) {
+    self.DOM.cell                      = function ( dom_element_line, cell_name ) {
         return dom_element_line.querySelector( '.shinken-list-cell[data-name="' + cell_name + '"]' );
     };
-    self.DOM.filter                   = function ( filter_name ) {
+    self.DOM.filter                    = function ( filter_name ) {
         return self.DOM.getIframe().querySelector( '.shinken-list-container-fix-header-filter .shinken-list-filter[data-name="' + filter_name + '"]' );
     };
-    self.DOM.filterInput              = function ( filter_name ) {
+    self.DOM.filterInput               = function ( filter_name ) {
         return self.DOM.filter( filter_name ).querySelector( '.shinken-input' );
     };
-    self.DOM.previousOwnerWithLineName = function (line_name) {
-        return self.lineWithName(line_name).querySelector("previous_owner")
+    self.DOM.previousOwnerWithLineName = function ( line_name ) {
+        return self.lineWithName( line_name ).querySelector( "previous_owner" );
     };
     
     //********************************************  GETTER   **************************************************//
@@ -169,7 +169,7 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER = (function ( self ) {
         }, timeout );
         return _to_return;
     };
-    self.TEST.checkPreviousOwner = function ( timeout, owner_name ) {
+    self.TEST.checkPreviousOwner        = function ( timeout, owner_name ) {
         var _to_return = 50;
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'checkPreviousOwner', owner_name );
         setTimeout( function () {
@@ -182,6 +182,18 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER = (function ( self ) {
         }, timeout );
         return _to_return;
     };
+    self.TEST.notificationState         = function ( timeout, line_name, to_test_blink, to_test_sound ) {
+        var _to_return = 50;
+        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'notificationState', line_name );
+        setTimeout( function () {
+            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
+            var _cell = self.DOM.cell( self.DOM.lineWithName( line_name ), "notifications" );
+            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( to_test_blink, !!_cell.querySelector( ".notifications_visual" ), 'test_blink_is_activate' );
+            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( to_test_sound, !!_cell.querySelector( ".notifications_sound" ), 'test_sound_is_activate' );
+            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
+        }, timeout );
+        return _to_return;
+    };
     _INTERNAL.testNumber                = function ( doms, value_expected, value_visible ) {
         SHINKEN.TOOLS.TEST_AUTO.___isArrayLengthEqualsTo( doms, value_expected, '' );
         if ( value_visible ) {
@@ -280,7 +292,7 @@ SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER = (function ( self ) {
         var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.clickOnHeaderMenuOption', header_name + " -> " + option_name );
         setTimeout( function () {
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
-            SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.headerButtonMenuOption( header_name,option_name ), false, 10 );
+            SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.headerButtonMenuOption( header_name, option_name ), false, 10 );
             SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
         }, timeout );
         return _to_return;
