@@ -11,7 +11,9 @@ MANAGER.EventManager = {
         MANAGER.__instance_window_modal_manager.setIframe( url, id );
     },
     closeModal           : function () {
-        MANAGER.__instance_window_modal_manager.close();
+        if ( MANAGER.__instance_window_modal_manager ) {
+            MANAGER.__instance_window_modal_manager.askDoClose();
+        }
     },
     closeNotify          : function ( notify_id ) {
         MANAGER.__instance_notify_manager.close( notify_id );
@@ -35,6 +37,14 @@ MANAGER.EventManager = {
         var _object             = MANAGER.__instance_property_distributor.findElement( parent_name, true );
         _object.onFocus();
     },
+    onFocusIn      : function ( event, event_name ) {
+        var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
+        if ( !_controller ) {
+            console.warn( "[EventManager - onFocusIn]", "Controller not found", event.target );
+            return;
+        }
+        _controller.onFocusIn( event, event_name );
+    },
     onFocusOut     : function ( event ) {
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
         _controller.onFocusOut( event );
@@ -51,30 +61,29 @@ MANAGER.EventManager = {
             }, 50 );
         }
     },
-    clickOnRadioBtn: function ( event ) {
+    clickOnRadioBtn: function ( event, event_name, param ) {
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
-        _controller.clickOnRadioBtn( event );
+        _controller.clickOnRadioBtn( event, event_name, param );
     },
     clickOnButton  : function ( event, event_name, param ) {
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
-        if ( !_controller ){
-            console.warn("[EventManager - clickOnButton]", "Controller not found", event.target );
+        if ( !_controller ) {
+            console.warn( "[EventManager - clickOnButton]", "Controller not found", event.target );
             return;
         }
         if ( !event_name ) {
             var _parent_dom_element = DOM.Service.findParentElementWithDataSet( event.target, 'name', 50 );
-            if ( !_parent_dom_element ) {
-                console.warn("[EventManager - clickOnButton]", "not element with data set 'name' found", event.target );
+            if ( _parent_dom_element ) {
+                event_name = _parent_dom_element.dataset.name;
+            }
+            else {
+                console.warn( "[EventManager - clickOnButton]", "not element with data set 'name' found", event.target );
                 return;
             }
-            event_name = _parent_dom_element.dataset.name;
         }
+        event.stopPropagation();
         _controller.clickOnButton( event, event_name, param );
     },
-    focusOnAnchor  : function ( event, uuid ) {
-        var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
-        _controller.focusOnAnchor( uuid );
-    },
     onKeyUp        : function ( event ) {
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
         _controller.onKeyUp( event );
@@ -88,16 +97,16 @@ MANAGER.EventManager = {
         _controller.onPaste( event );
     },
     //********************************************  DRAG & DROP ******************************************//
-    onDragStart: function ( _controller_name, element_name ) {
+    onDragStart: function ( _controller_name, element_name, origin_x, origin_y ) {
         var _controller = MANAGER.DistributorControllerManager.getController( _controller_name );
         if ( _controller ) {
-            _controller.onDragStart( element_name );
+            _controller.onDragStart( element_name, origin_x, origin_y );
         }
     },
-    onDragMove : function ( _controller_name, element_name ) {
+    onDragMove : function ( _controller_name, element_name, delta_x, delta_y ) {
         var _controller = MANAGER.DistributorControllerManager.getController( _controller_name );
         if ( _controller ) {
-            _controller.onDragMove( element_name );
+            _controller.onDragMove( element_name, delta_x, delta_y );
         }
     },
     onDragStop : function ( _controller_name, element_name ) {
@@ -107,16 +116,16 @@ MANAGER.EventManager = {
         }
     },
     //********************************************  RESIZE ******************************************//
-    onResizeStart: function ( _controller_name, element_name ) {
+    onResizeStart: function ( _controller_name, element_name, width, height ) {
         var _controller = MANAGER.DistributorControllerManager.getController( _controller_name );
         if ( _controller ) {
             _controller.onResizeStart( element_name );
         }
     },
-    onResizeMove : function ( _controller_name, element_name ) {
+    onResizeMove : function ( _controller_name, element_name, width, height ) {
         var _controller = MANAGER.DistributorControllerManager.getController( _controller_name );
         if ( _controller ) {
-            _controller.onResizeMove( element_name );
+            _controller.onResizeMove( element_name, width, height );
         }
     },
     onResizeStop : function ( _controller_name, element_name ) {
@@ -167,15 +176,18 @@ MANAGER.EventManager = {
             window_name = _nav_tab.dataset.name;
         }
         var _parent_window = MANAGER.__instance_window_distributor.findParentWindow( name );
-        
+    
         _parent_window.clickOnWindow( window_name );
         if ( update_url ) {
             SHINKEN.HIGHWAY.goToElementTab( window_name );
         }
         
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
-        if ( _controller ) {
+        try {
             _controller.computeSizes();
+            //NOT ALWAYS EXISTING
+        }
+        catch ( e ) {
         }
     },
     //********************************************  PROPERTIES CHECK  ******************************************//
@@ -184,9 +196,9 @@ MANAGER.EventManager = {
         _controller.clickOnCheckboxInput( event );
     },
     //********************************************  PROPERTIES STRING_INPUT  ******************************************//
-    onChangeOnInput: function ( event ) {
+    onChangeOnInput: function ( event, event_name, param ) {
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event );
-        _controller.onChangeOnInput( event );
+        _controller.onChangeOnInput( event, event_name, param );
     },
     onResize       : function ( dom_element ) {
         var _parent_dom_element = DOM.Service.findParentElementWithClass( dom_element, PROPERTY.CONST.CLASS.SKINKEN_LINE, 25 );
@@ -209,10 +221,10 @@ MANAGER.EventManager = {
         _object.clickOnBtnPlus( event );
         MANAGER.ListenerEventManager.askAfterActionProperty( _object );
     },
-    clickOnSelector          : function ( event, parent_name, controller_name ) {
+    clickOnSelector          : function ( event, param, controller_name ) {
         event.stopPropagation();
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event, controller_name );
-        _controller.clickOnSelector( event, parent_name );
+        _controller.clickOnSelector( event, param );
     },
     clickOnAllItemsSelector  : function ( parent_name, limit ) {
         var _object = MANAGER.__instance_property_distributor.findElement( parent_name, true );
@@ -375,10 +387,10 @@ MANAGER.EventManager = {
             _controller.onClick( event );
         }
     },
-    onScroll                    : function ( event, controller_name ) {
+    onScroll                    : function ( event, controller_name, param ) {
         var _controller = MANAGER.DistributorControllerManager.findControllerByEvent( event, controller_name );
         if ( _controller ) {
-            _controller.onScroll( event );
+            _controller.onScroll( event, param );
         }
     },
     clickOnForcedHelpButton     : function ( event, dom_element ) {
