@@ -20,13 +20,6 @@ from shinkensolutions.lib_checks.common import Result, HTMLTag, COLOR, EXIT_STAT
 # note: it's imported from graphite 1.1.8/.../metrics/views/py :: get_metrics_count()
 #####
 
-
-try:
-    import pwd
-    import grp
-except ImportError:  # windows
-    pwd = grp = None
-
 if TYPE_CHECKING:
     from shinken.misc.type_hint import Optional, Callable
 
